
/* SCHEME->C */

#include <objects.h>

DEFSTRING( t3059, "The programs are now installed.  Enjoy!!", 40 );
DEFSTATICTSCP2( c2898, t3059 );
DEFSTRING( t3060, "Argument not a CHAR: ~s", 23 );
DEFSTATICTSCP2( c2896, t3060 );
DEFSTRING( t3061, "CHAR->INTEGER", 13 );
DEFSTATICTSCP( c2895 );
DEFSTRING( t3062, "Argument(s) not CHAR: ~s ~s", 27 );
DEFSTATICTSCP2( c2721, t3062 );
DEFSTRING( t3063, "CHAR=?", 6 );
DEFSTATICTSCP( c2720 );
DEFSTRING( t3064, "Argument is out of range: ~s", 28 );
DEFSTATICTSCP2( c2706, t3064 );
DEFSTRING( t3065, "Argument is not a STRING: ~s", 28 );
DEFSTATICTSCP2( c2705, t3065 );
DEFSTRING( t3066, "STRING-LENGTH", 13 );
DEFSTATICTSCP( c2704 );
DEFSTRING( t3067, "Argument is not an INTEGER: ~s", 30 );
DEFSTATICTSCP2( c2683, t3067 );
DEFSTRING( t3068, "STRING-REF", 10 );
DEFSTATICTSCP( c2682 );
DEFSTRING( t3069, ",", 1 );
DEFSTATICTSCP2( c2668, t3069 );
DEFSTRING( t3070, " ", 1 );
DEFSTATICTSCP2( c2632, t3070 );
DEFSTRING( t3071, "Argument is not a SYMBOL: ~s", 28 );
DEFSTATICTSCP2( c2627, t3071 );
DEFSTRING( t3072, "SYMBOL->STRING", 14 );
DEFSTATICTSCP( c2626 );
DEFSTATICTSCP( c2610 );
DEFSTRING( t3073, ", ", 2 );
DEFSTATICTSCP2( c2583, t3073 );
DEFSTRING( t3074, "Argument not an INTEGER: ~s", 27 );
DEFSTATICTSCP2( c1724, t3074 );
DEFSTRING( t3075, "EVEN?", 5 );
DEFSTATICTSCP( c1723 );
DEFSTRING( t3076, "Argument not a PAIR: ~s", 23 );
DEFSTATICTSCP2( c1498, t3076 );
DEFSTRING( t3077, "SET-CAR!", 8 );
DEFSTATICTSCP( c1497 );
DEFSTRING( t3078, "SW", 2 );
DEFSTATICTSCP( c1259 );
DEFSTRING( t3079, "NW", 2 );
DEFSTATICTSCP( c1252 );
DEFSTRING( t3080, "R", 1 );
DEFSTATICTSCP( c1113 );
DEFSTRING( t3081, "D", 1 );
DEFSTATICTSCP( c1109 );
DEFSTRING( t3082, "U", 1 );
DEFSTATICTSCP( c1104 );
DEFSTRING( t3083, "NE", 2 );
DEFSTATICTSCP( c1099 );
DEFSTRING( t3084, "JUNK", 4 );
DEFSTATICTSCP( c1098 );
DEFSTRING( t3085, "SE", 2 );
DEFSTATICTSCP( c1097 );
DEFSTRING( t3086, "L", 1 );
DEFSTATICTSCP( c1092 );

static void  init_constants()
{
        c2895 = STRINGTOSYMBOL( U_TX( ADR( t3061 ) ) );
        CONSTANTEXP( ADR( c2895 ) );
        c2720 = STRINGTOSYMBOL( U_TX( ADR( t3063 ) ) );
        CONSTANTEXP( ADR( c2720 ) );
        c2704 = STRINGTOSYMBOL( U_TX( ADR( t3066 ) ) );
        CONSTANTEXP( ADR( c2704 ) );
        c2682 = STRINGTOSYMBOL( U_TX( ADR( t3068 ) ) );
        CONSTANTEXP( ADR( c2682 ) );
        c2626 = STRINGTOSYMBOL( U_TX( ADR( t3072 ) ) );
        CONSTANTEXP( ADR( c2626 ) );
        c2610 = EMPTYLIST;
        c2610 = CONS( _TSCP( 2578 ), c2610 );
        CONSTANTEXP( ADR( c2610 ) );
        c1723 = STRINGTOSYMBOL( U_TX( ADR( t3075 ) ) );
        CONSTANTEXP( ADR( c1723 ) );
        c1497 = STRINGTOSYMBOL( U_TX( ADR( t3077 ) ) );
        CONSTANTEXP( ADR( c1497 ) );
        c1259 = STRINGTOSYMBOL( U_TX( ADR( t3078 ) ) );
        CONSTANTEXP( ADR( c1259 ) );
        c1252 = STRINGTOSYMBOL( U_TX( ADR( t3079 ) ) );
        CONSTANTEXP( ADR( c1252 ) );
        c1113 = STRINGTOSYMBOL( U_TX( ADR( t3080 ) ) );
        CONSTANTEXP( ADR( c1113 ) );
        c1109 = STRINGTOSYMBOL( U_TX( ADR( t3081 ) ) );
        CONSTANTEXP( ADR( c1109 ) );
        c1104 = STRINGTOSYMBOL( U_TX( ADR( t3082 ) ) );
        CONSTANTEXP( ADR( c1104 ) );
        c1099 = STRINGTOSYMBOL( U_TX( ADR( t3083 ) ) );
        CONSTANTEXP( ADR( c1099 ) );
        c1098 = STRINGTOSYMBOL( U_TX( ADR( t3084 ) ) );
        CONSTANTEXP( ADR( c1098 ) );
        c1097 = STRINGTOSYMBOL( U_TX( ADR( t3085 ) ) );
        CONSTANTEXP( ADR( c1097 ) );
        c1092 = STRINGTOSYMBOL( U_TX( ADR( t3086 ) ) );
        CONSTANTEXP( ADR( c1092 ) );
}

DEFTSCP( comma_call_2fcc_v );
DEFSTRING( t3087, "CALL/CC", 7 );
EXTERNTSCPP( sc_ntinuation_1af38b9f );
EXTERNTSCP( sc_ntinuation_1af38b9f_v );
DEFTSCP( comma_newlist_v );
DEFSTRING( t3088, "NEWLIST", 7 );
EXTERNTSCPP( scrt1__24__car_2derror );
EXTERNTSCP( scrt1__24__car_2derror_v );
EXTERNTSCPP( sc_cons );
EXTERNTSCP( sc_cons_v );
EXTERNTSCPP( comma_newlist );
EXTERNTSCP( comma_newlist_v );

TSCP  comma_newlist( l1010 )
        TSCP  l1010;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3088 ) ) );
        if  ( EQ( UNSIGNED( l1010 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3090;
        if  ( EQ( TSCPTAG( l1010 ), PAIRTAG ) )  goto  L3095;
        scrt1__24__car_2derror( l1010 );
L3095:
        X1 = PAIR_CAR( l1010 );
        if  ( NEQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3092;
        X2 = PAIR_CAR( l1010 );
        X1 = comma_newlist( X2 );
        X3 = PAIR_CDR( l1010 );
        X2 = comma_newlist( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3092:
        if  ( EQ( TSCPTAG( l1010 ), PAIRTAG ) )  goto  L3100;
        scrt1__24__car_2derror( l1010 );
L3100:
        X1 = PAIR_CAR( l1010 );
        X3 = PAIR_CDR( l1010 );
        X2 = comma_newlist( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3090:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_carof_v );
DEFSTRING( t3103, "CAROF", 5 );
DEFSTRING( t3106, "comma_l1041 [inside CAROF]", 26 );

TSCP  comma_l1041( x1042, y1043, c3105 )
        TSCP  x1042, y1043, c3105;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3106 ) ) );
        X1 = DISPLAY( 0 );
        DISPLAY( 0 ) = CLOSURE_VAR( c3105, 0 );
        X4 = DISPLAY( 0 );
        X4 = UNKNOWNCALL( X4, 2 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( x1042, 
                                          y1043, 
                                          PROCEDURE_CLOSURE( X4 ) );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L3109;
        scrt1__24__car_2derror( X3 );
L3109:
        X2 = PAIR_CAR( X3 );
        DISPLAY( 0 ) = X1;
        POPSTACKTRACE( X2 );
}

TSCP  comma_carof( p1040 )
        TSCP  p1040;
{
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3103 ) ) );
        DISPLAY( 0 ) = p1040;
        SDVAL = MAKEPROCEDURE( 2, 
                               0, 
                               comma_l1041, 
                               MAKECLOSURE( EMPTYLIST, 
                                            1, DISPLAY( 0 ) ) );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_add1_v );
DEFSTRING( t3111, "ADD1", 4 );
EXTERNTSCPP( scrt2__2b_2dtwo );
EXTERNTSCP( scrt2__2b_2dtwo_v );

TSCP  comma_add1( n1050 )
        TSCP  n1050;
{
        PUSHSTACKTRACE( U_TX( ADR( t3111 ) ) );
        if  ( BITAND( BITOR( INT( _TSCP( 4 ) ), 
                             INT( n1050 ) ), 
                      3 ) )  goto  L3113;
        POPSTACKTRACE( _TSCP( IPLUS( INT( _TSCP( 4 ) ), 
                                     INT( n1050 ) ) ) );
L3113:
        POPSTACKTRACE( scrt2__2b_2dtwo( _TSCP( 4 ), n1050 ) );
}

DEFTSCP( comma_sub1_v );
DEFSTRING( t3115, "SUB1", 4 );
EXTERNTSCPP( scrt2__2d_2dtwo );
EXTERNTSCP( scrt2__2d_2dtwo_v );

TSCP  comma_sub1( n1060 )
        TSCP  n1060;
{
        PUSHSTACKTRACE( U_TX( ADR( t3115 ) ) );
        if  ( BITAND( BITOR( INT( n1060 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3117;
        POPSTACKTRACE( _TSCP( IDIFFERENCE( INT( n1060 ), 
                                           INT( _TSCP( 4 ) ) ) ) );
L3117:
        POPSTACKTRACE( scrt2__2d_2dtwo( n1060, _TSCP( 4 ) ) );
}

DEFTSCP( comma_int_2d_3erep_v );
DEFSTRING( t3119, "INT->REP", 8 );
EXTERNTSCPP( scrt2_zero_3f );
EXTERNTSCP( scrt2_zero_3f_v );
EXTERNTSCPP( scrt2_positive_3f );
EXTERNTSCP( scrt2_positive_3f_v );
DEFSTRING( t3164, "INT->REP-HELPER [inside INT->REP]", 33 );
EXTERNTSCPP( scrt2__3d_2dtwo );
EXTERNTSCP( scrt2__3d_2dtwo_v );
EXTERNTSCPP( scrt1_append_2dtwo );
EXTERNTSCP( scrt1_append_2dtwo_v );
EXTERNTSCPP( comma_i1129 );

TSCP  comma_i1129( m1131 )
        TSCP  m1131;
{
        TSCP  X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3164 ) ) );
        if  ( BITAND( BITOR( INT( m1131 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3167;
        if  ( NEQ( UNSIGNED( m1131 ), 
                   UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3171;
        POPSTACKTRACE( EMPTYLIST );
L3167:
        if  ( FALSE( scrt2__3d_2dtwo( m1131, _TSCP( 4 ) ) ) )  goto  L3171;
        POPSTACKTRACE( EMPTYLIST );
L3171:
        X2 = comma_sub1( m1131 );
        X1 = comma_i1129( X2 );
        X9 = sc_cons( c1104, EMPTYLIST );
        X8 = sc_cons( m1131, X9 );
        X7 = sc_cons( c1109, X8 );
        X6 = sc_cons( m1131, X7 );
        X5 = sc_cons( PAIR_CAR( DISPLAY( 0 ) ), X6 );
        X4 = X5;
        X3 = sc_cons( X4, EMPTYLIST );
        X2 = X3;
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
}

EXTERNTSCPP( scrt2_abs );
EXTERNTSCP( scrt2_abs_v );

TSCP  comma_int_2d_3erep( n1069 )
        TSCP  n1069;
{
        TSCP  X13, 
              X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3119 ) ) );
        if  ( NEQ( TSCPTAG( n1069 ), FIXNUMTAG ) )  goto  L3122;
        if  ( EQ( UNSIGNED( n1069 ), 
                  UNSIGNED( _TSCP( 0 ) ) ) )  goto  L3126;
        goto L3127;
L3122:
        if  ( FALSE( scrt2_zero_3f( n1069 ) ) )  goto  L3127;
L3126:
        X4 = sc_cons( c1098, EMPTYLIST );
        X3 = sc_cons( c1099, X4 );
        X2 = X3;
        X6 = sc_cons( c1098, EMPTYLIST );
        X5 = sc_cons( c1098, X6 );
        X4 = X5;
        X8 = sc_cons( c1098, EMPTYLIST );
        X7 = sc_cons( c1097, X8 );
        X6 = X7;
        X10 = sc_cons( c1098, EMPTYLIST );
        X9 = sc_cons( c1098, X10 );
        X8 = X9;
        X7 = sc_cons( X8, EMPTYLIST );
        X5 = sc_cons( X6, X7 );
        X3 = sc_cons( X4, X5 );
        X1 = sc_cons( X2, X3 );
        SDVAL = X1;
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
L3127:
        DISPLAY( 0 ) = c1098;
        X1 = c1098;
        X2 = c1098;
        X2 = CONS( X2, EMPTYLIST );
        X1 = CONS( X1, EMPTYLIST );
        DISPLAY( 0 ) = CONS( DISPLAY( 0 ), EMPTYLIST );
        if  ( NEQ( TSCPTAG( n1069 ), FIXNUMTAG ) )  goto  L3138;
        if  ( GT( INT( n1069 ), 0 ) )  goto  L3142;
        goto L3143;
L3138:
        if  ( TRUE( scrt2_positive_3f( n1069 ) ) )  goto  L3142;
L3143:
        X3 = c1092;
        SETGEN( PAIR_CAR( DISPLAY( 0 ) ), X3 );
        X10 = sc_cons( c1098, EMPTYLIST );
        X9 = sc_cons( c1099, X10 );
        X8 = sc_cons( c1098, X9 );
        X7 = sc_cons( c1097, X8 );
        X6 = sc_cons( c1092, X7 );
        X5 = X6;
        X4 = sc_cons( X5, EMPTYLIST );
        X3 = X4;
        SETGEN( PAIR_CAR( X1 ), X3 );
        X7 = sc_cons( c1104, EMPTYLIST );
        X6 = sc_cons( _TSCP( 4 ), X7 );
        X5 = X6;
        X9 = sc_cons( c1098, EMPTYLIST );
        X8 = sc_cons( c1098, X9 );
        X7 = X8;
        X11 = sc_cons( c1109, EMPTYLIST );
        X10 = sc_cons( _TSCP( 4 ), X11 );
        X9 = X10;
        X13 = sc_cons( c1098, EMPTYLIST );
        X12 = sc_cons( c1098, X13 );
        X11 = X12;
        X10 = sc_cons( X11, EMPTYLIST );
        X8 = sc_cons( X9, X10 );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X3 = X4;
        SETGEN( PAIR_CAR( X2 ), X3 );
        goto L3146;
L3142:
        X3 = c1113;
        SETGEN( PAIR_CAR( DISPLAY( 0 ) ), X3 );
        X10 = sc_cons( c1098, EMPTYLIST );
        X9 = sc_cons( c1097, X10 );
        X8 = sc_cons( c1098, X9 );
        X7 = sc_cons( c1099, X8 );
        X6 = sc_cons( c1113, X7 );
        X5 = X6;
        X4 = sc_cons( X5, EMPTYLIST );
        X3 = X4;
        SETGEN( PAIR_CAR( X1 ), X3 );
        X7 = sc_cons( c1109, EMPTYLIST );
        X6 = sc_cons( _TSCP( 4 ), X7 );
        X5 = X6;
        X9 = sc_cons( c1098, EMPTYLIST );
        X8 = sc_cons( c1098, X9 );
        X7 = X8;
        X11 = sc_cons( c1104, EMPTYLIST );
        X10 = sc_cons( _TSCP( 4 ), X11 );
        X9 = X10;
        X13 = sc_cons( c1098, EMPTYLIST );
        X12 = sc_cons( c1098, X13 );
        X11 = X12;
        X10 = sc_cons( X11, EMPTYLIST );
        X8 = sc_cons( X9, X10 );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X3 = X4;
        SETGEN( PAIR_CAR( X2 ), X3 );
L3146:
        if  ( NEQ( TSCPTAG( n1069 ), FIXNUMTAG ) )  goto  L3176;
        if  ( LT( INT( n1069 ), 0 ) )  goto  L3181;
        X5 = n1069;
        goto L3177;
L3181:
        X5 = _TSCP( INEGATE( INT( n1069 ) ) );
        goto L3177;
L3176:
        X5 = scrt2_abs( n1069 );
L3177:
        X4 = comma_i1129( X5 );
        X3 = scrt1_append_2dtwo( X4, PAIR_CAR( X1 ) );
        SDVAL = scrt1_append_2dtwo( PAIR_CAR( X2 ), X3 );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_row_v );
DEFSTRING( t3183, "ROW", 3 );
EXTERNTSCPP( scrt1_cadddr );
EXTERNTSCP( scrt1_cadddr_v );
EXTERNTSCPP( scrt1__24__cdr_2derror );
EXTERNTSCP( scrt1__24__cdr_2derror_v );

TSCP  comma_row( n1169, r1170 )
        TSCP  n1169, r1170;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t3183 ) ) );
L3184:
        if  ( BITAND( BITOR( INT( n1169 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3186;
        if  ( EQ( UNSIGNED( n1169 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3190;
        goto L3191;
L3186:
        if  ( FALSE( scrt2__3d_2dtwo( n1169, _TSCP( 4 ) ) ) )  goto  L3191;
L3190:
        if  ( EQ( TSCPTAG( r1170 ), PAIRTAG ) )  goto  L3195;
        scrt1__24__cdr_2derror( r1170 );
L3195:
        X1 = PAIR_CDR( r1170 );
        POPSTACKTRACE( scrt1_cadddr( X1 ) );
L3191:
        X1 = comma_sub1( n1169 );
        if  ( EQ( TSCPTAG( r1170 ), PAIRTAG ) )  goto  L3198;
        scrt1__24__cdr_2derror( r1170 );
L3198:
        r1170 = PAIR_CDR( r1170 );
        n1169 = X1;
        goto L3184;
}

DEFTSCP( comma_direction_2dcell_v );
DEFSTRING( t3200, "DIRECTION-CELL", 14 );

TSCP  comma_direction_2dcell( n1190, r1191 )
        TSCP  n1190, r1191;
{
        PUSHSTACKTRACE( U_TX( ADR( t3200 ) ) );
        POPSTACKTRACE( comma_row( n1190, r1191 ) );
}

DEFTSCP( comma_direction_v );
DEFSTRING( t3202, "DIRECTION", 9 );
DEFTSCP( comma_over_2dknot_2dcell_v );
DEFSTRING( t3203, "OVER-KNOT-CELL", 14 );

TSCP  comma_over_2dknot_2dcell( n1195, r1196 )
        TSCP  n1195, r1196;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t3203 ) ) );
        X1 = comma_row( n1195, r1196 );
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3206;
        scrt1__24__cdr_2derror( X1 );
L3206:
        POPSTACKTRACE( PAIR_CDR( X1 ) );
}

DEFTSCP( comma_over_2dknot_v );
DEFSTRING( t3208, "OVER-KNOT", 9 );
DEFTSCP( comma_over_2dpos_2dcell_v );
DEFSTRING( t3209, "OVER-POS-CELL", 13 );

TSCP  comma_over_2dpos_2dcell( n1204, r1205 )
        TSCP  n1204, r1205;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3209 ) ) );
        X1 = comma_row( n1204, r1205 );
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3213;
        scrt1__24__cdr_2derror( X1 );
L3213:
        X2 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3216;
        scrt1__24__cdr_2derror( X2 );
L3216:
        POPSTACKTRACE( PAIR_CDR( X2 ) );
}

DEFTSCP( comma_over_2dpos_v );
DEFSTRING( t3218, "OVER-POS", 8 );
DEFTSCP( comma_under_2dknot_2dcell_v );
DEFSTRING( t3219, "UNDER-KNOT-CELL", 15 );
EXTERNTSCPP( scrt1_cdddr );
EXTERNTSCP( scrt1_cdddr_v );

TSCP  comma_under_2dknot_2dcell( n1219, r1220 )
        TSCP  n1219, r1220;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t3219 ) ) );
        X1 = comma_row( n1219, r1220 );
        POPSTACKTRACE( scrt1_cdddr( X1 ) );
}

DEFTSCP( comma_under_2dknot_v );
DEFSTRING( t3221, "UNDER-KNOT", 10 );
DEFTSCP( comma_under_2dpos_2dcell_v );
DEFSTRING( t3222, "UNDER-POS-CELL", 14 );

TSCP  comma_under_2dpos_2dcell( n1224, r1225 )
        TSCP  n1224, r1225;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3222 ) ) );
        X2 = comma_row( n1224, r1225 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3225;
        scrt1__24__cdr_2derror( X2 );
L3225:
        X1 = PAIR_CDR( X2 );
        POPSTACKTRACE( scrt1_cdddr( X1 ) );
}

DEFTSCP( comma_under_2dpos_v );
DEFSTRING( t3227, "UNDER-POS", 9 );
DEFTSCP( comma_compose_v );
DEFSTRING( t3228, "COMPOSE", 7 );
DEFSTRING( t3231, "comma_l1235 [inside COMPOSE]", 28 );

TSCP  comma_l1235( x1236, c3230 )
        TSCP  x1236, c3230;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3231 ) ) );
        X1 = DISPLAY( 1 );
        DISPLAY( 1 ) = CLOSURE_VAR( c3230, 0 );
        X2 = DISPLAY( 0 );
        DISPLAY( 0 ) = CLOSURE_VAR( c3230, 1 );
        X6 = DISPLAY( 1 );
        X6 = UNKNOWNCALL( X6, 1 );
        X5 = VIA( PROCEDURE_CODE( X6 ) )( x1236, 
                                          PROCEDURE_CLOSURE( X6 ) );
        X4 = DISPLAY( 0 );
        X4 = UNKNOWNCALL( X4, 1 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( X5, 
                                          PROCEDURE_CLOSURE( X4 ) );
        DISPLAY( 1 ) = X1;
        DISPLAY( 0 ) = X2;
        POPSTACKTRACE( X3 );
}

TSCP  comma_compose( f1233, g1234 )
        TSCP  f1233, g1234;
{
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SD1 = DISPLAY( 1 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3228 ) ) );
        DISPLAY( 0 ) = f1233;
        DISPLAY( 1 ) = g1234;
        SDVAL = MAKEPROCEDURE( 1, 
                               0, 
                               comma_l1235, 
                               MAKECLOSURE( EMPTYLIST, 
                                            2, 
                                            DISPLAY( 1 ), 
                                            DISPLAY( 0 ) ) );
        DISPLAY( 0 ) = SD0;
        DISPLAY( 1 ) = SD1;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_nw_2dknot_v );
DEFSTRING( t3233, "NW-KNOT", 7 );
EXTERNTSCPP( scrt1_caar );
EXTERNTSCP( scrt1_caar_v );
DEFTSCP( comma_nw_2dpos_v );
DEFSTRING( t3234, "NW-POS", 6 );
EXTERNTSCPP( scrt1_cadar );
EXTERNTSCP( scrt1_cadar_v );
DEFTSCP( comma_ne_2dknot_v );
DEFSTRING( t3235, "NE-KNOT", 7 );
EXTERNTSCPP( scrt1_caadr );
EXTERNTSCP( scrt1_caadr_v );
DEFTSCP( comma_ne_2dpos_v );
DEFSTRING( t3236, "NE-POS", 6 );
EXTERNTSCPP( scrt1_cadadr );
EXTERNTSCP( scrt1_cadadr_v );
DEFTSCP( comma_sw_2dknot_v );
DEFSTRING( t3237, "SW-KNOT", 7 );
EXTERNTSCPP( scrt1_caaddr );
EXTERNTSCP( scrt1_caaddr_v );
DEFTSCP( comma_sw_2dpos_v );
DEFSTRING( t3238, "SW-POS", 6 );
EXTERNTSCPP( scrt1_cdr );
EXTERNTSCP( scrt1_cdr_v );
DEFTSCP( comma_se_2dknot_v );
DEFSTRING( t3239, "SE-KNOT", 7 );
DEFTSCP( comma_se_2dpos_v );
DEFSTRING( t3240, "SE-POS", 6 );
EXTERNTSCPP( scrt1_cddr );
EXTERNTSCP( scrt1_cddr_v );
DEFTSCP( comma_select_2dorigin_v );
DEFSTRING( t3241, "SELECT-ORIGIN", 13 );
EXTERNTSCPP( scrt1_car );
EXTERNTSCP( scrt1_car_v );
EXTERNTSCPP( scrt1_cadr );
EXTERNTSCP( scrt1_cadr_v );
EXTERNTSCPP( scrt1_caddr );
EXTERNTSCP( scrt1_caddr_v );

TSCP  comma_select_2dorigin( c1247, r1248 )
        TSCP  c1247, r1248;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t3241 ) ) );
        if  ( NEQ( UNSIGNED( c1247 ), UNSIGNED( c1252 ) ) )  goto  L3243;
        X1 = scrt1_car_v;
        goto L3250;
L3243:
        if  ( NEQ( UNSIGNED( c1247 ), UNSIGNED( c1099 ) ) )  goto  L3245;
        X1 = scrt1_cadr_v;
        goto L3250;
L3245:
        if  ( NEQ( UNSIGNED( c1247 ), UNSIGNED( c1259 ) ) )  goto  L3247;
        X1 = scrt1_caddr_v;
        goto L3250;
L3247:
        if  ( NEQ( UNSIGNED( c1247 ), UNSIGNED( c1097 ) ) )  goto  L3249;
        X1 = scrt1_cadddr_v;
        goto L3250;
L3249:
        X1 = FALSEVALUE;
L3250:
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( r1248, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
}

DEFTSCP( comma_mult0_v );
DEFSTRING( t3251, "MULT0", 5 );
DEFSTRING( t3254, "MULT0-HELPER [inside MULT0]", 27 );
EXTERNTSCPP( comma_m1267 );

TSCP  comma_m1267( l1270 )
        TSCP  l1270;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3254 ) ) );
        if  ( EQ( UNSIGNED( l1270 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3256;
        if  ( EQ( TSCPTAG( l1270 ), PAIRTAG ) )  goto  L3261;
        scrt1__24__car_2derror( l1270 );
L3261:
        X2 = PAIR_CAR( l1270 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1099 ) ) )  goto  L3258;
        X1 = c1259;
        goto L3274;
L3258:
        if  ( EQ( TSCPTAG( l1270 ), PAIRTAG ) )  goto  L3266;
        scrt1__24__car_2derror( l1270 );
L3266:
        X2 = PAIR_CAR( l1270 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1259 ) ) )  goto  L3263;
        X1 = c1099;
        goto L3274;
L3263:
        if  ( EQ( TSCPTAG( l1270 ), PAIRTAG ) )  goto  L3271;
        scrt1__24__car_2derror( l1270 );
L3271:
        X2 = PAIR_CAR( l1270 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1113 ) ) )  goto  L3268;
        X1 = c1092;
        goto L3274;
L3268:
        if  ( EQ( TSCPTAG( l1270 ), PAIRTAG ) )  goto  L3276;
        scrt1__24__car_2derror( l1270 );
L3276:
        X2 = PAIR_CAR( l1270 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1092 ) ) )  goto  L3273;
        X1 = c1113;
        goto L3274;
L3273:
        if  ( EQ( TSCPTAG( l1270 ), PAIRTAG ) )  goto  L3279;
        scrt1__24__car_2derror( l1270 );
L3279:
        X1 = PAIR_CAR( l1270 );
L3274:
        X3 = PAIR_CDR( l1270 );
        X2 = comma_m1267( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3256:
        POPSTACKTRACE( EMPTYLIST );
}

DEFSTRING( t3282, "MULT0-HELPER2 [inside MULT0]", 28 );
EXTERNTSCPP( comma_m1268 );

TSCP  comma_m1268( l1313 )
        TSCP  l1313;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3282 ) ) );
        if  ( EQ( UNSIGNED( l1313 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3284;
        if  ( EQ( TSCPTAG( l1313 ), PAIRTAG ) )  goto  L3287;
        scrt1__24__car_2derror( l1313 );
L3287:
        X2 = PAIR_CAR( l1313 );
        X1 = comma_m1267( X2 );
        X3 = PAIR_CDR( l1313 );
        X2 = comma_m1268( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3284:
        POPSTACKTRACE( EMPTYLIST );
}

EXTERNTSCPP( scrt1_cddddr );
EXTERNTSCP( scrt1_cddddr_v );

TSCP  comma_mult0( r1265 )
        TSCP  r1265;
{
        TSCP  X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3251 ) ) );
        if  ( EQ( TSCPTAG( r1265 ), PAIRTAG ) )  goto  L3291;
        scrt1__24__car_2derror( r1265 );
L3291:
        X3 = PAIR_CAR( r1265 );
        X5 = scrt1_caddr( r1265 );
        X8 = PAIR_CDR( r1265 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto  L3295;
        scrt1__24__car_2derror( X8 );
L3295:
        X7 = PAIR_CAR( X8 );
        X9 = scrt1_cadddr( r1265 );
        X8 = sc_cons( X9, EMPTYLIST );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
        X3 = scrt1_cddddr( r1265 );
        X2 = comma_m1268( X3 );
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
}

DEFTSCP( comma_recur_v );
DEFSTRING( t3298, "RECUR", 5 );

TSCP  comma_recur( r1345 )
        TSCP  r1345;
{
        TSCP  X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3298 ) ) );
        if  ( EQ( TSCPTAG( r1345 ), PAIRTAG ) )  goto  L3301;
        scrt1__24__car_2derror( r1345 );
L3301:
        X3 = PAIR_CAR( r1345 );
        X6 = PAIR_CDR( r1345 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3305;
        scrt1__24__car_2derror( X6 );
L3305:
        X5 = PAIR_CAR( X6 );
        X7 = scrt1_caddr( r1345 );
        X9 = scrt1_cadddr( r1345 );
        X8 = sc_cons( X9, EMPTYLIST );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
        X3 = scrt1_cddddr( r1345 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L3309;
        scrt1__24__cdr_2derror( X3 );
L3309:
        X2 = PAIR_CDR( X3 );
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
}

DEFTSCP( comma_renumber_v );
DEFSTRING( t3311, "RENUMBER", 8 );
DEFSTRING( t3314, "RENUMBER-HELPER [inside RENUMBER]", 33 );
EXTERNTSCPP( comma_r1371 );

TSCP  comma_r1371( r1374 )
        TSCP  r1374;
{
        TSCP  X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3314 ) ) );
        X1 = scrt1_cddddr( r1374 );
        if  ( EQ( UNSIGNED( X1 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3316;
        X4 = comma_direction_v;
        X4 = UNKNOWNCALL( X4, 2 );
        X3 = VIA( PROCEDURE_CODE( X4 ) )( _TSCP( 4 ), 
                                          r1374, 
                                          PROCEDURE_CLOSURE( X4 ) );
        X7 = comma_over_2dknot_v;
        X7 = UNKNOWNCALL( X7, 2 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( _TSCP( 4 ), 
                                          r1374, 
                                          PROCEDURE_CLOSURE( X7 ) );
        X7 = BOOLEAN( EQ( TSCPTAG( X6 ), FIXNUMTAG ) );
        if  ( TRUE( X7 ) )  goto  L3323;
        if  ( AND( EQ( TSCPTAG( X6 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X6 ), FLOATTAG ) ) )  goto  L3323;
        X5 = X6;
        goto L3328;
L3323:
        if  ( BITAND( BITOR( INT( DISPLAY( 0 ) ), 
                             INT( X6 ) ), 
                      3 ) )  goto  L3327;
        X5 = _TSCP( IPLUS( INT( DISPLAY( 0 ) ), 
                           INT( X6 ) ) );
        goto L3328;
L3327:
        X5 = scrt2__2b_2dtwo( DISPLAY( 0 ), X6 );
L3328:
        X8 = comma_over_2dpos_v;
        X8 = UNKNOWNCALL( X8, 2 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( _TSCP( 4 ), 
                                          r1374, 
                                          PROCEDURE_CLOSURE( X8 ) );
        X11 = comma_under_2dknot_v;
        X11 = UNKNOWNCALL( X11, 2 );
        X10 = VIA( PROCEDURE_CODE( X11 ) )( _TSCP( 4 ), 
                                            r1374, 
                                            PROCEDURE_CLOSURE( X11 ) );
        X11 = BOOLEAN( EQ( TSCPTAG( X10 ), FIXNUMTAG ) );
        if  ( TRUE( X11 ) )  goto  L3334;
        if  ( AND( EQ( TSCPTAG( X10 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X10 ), FLOATTAG ) ) )  goto  L3334;
        X9 = X10;
        goto L3339;
L3334:
        if  ( BITAND( BITOR( INT( DISPLAY( 0 ) ), 
                             INT( X10 ) ), 
                      3 ) )  goto  L3338;
        X9 = _TSCP( IPLUS( INT( DISPLAY( 0 ) ), 
                           INT( X10 ) ) );
        goto L3339;
L3338:
        X9 = scrt2__2b_2dtwo( DISPLAY( 0 ), X10 );
L3339:
        X12 = comma_under_2dpos_v;
        X12 = UNKNOWNCALL( X12, 2 );
        X11 = VIA( PROCEDURE_CODE( X12 ) )( _TSCP( 4 ), 
                                            r1374, 
                                            PROCEDURE_CLOSURE( X12 ) );
        X10 = sc_cons( X11, EMPTYLIST );
        X8 = sc_cons( X9, X10 );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
        X3 = comma_recur( r1374 );
        X2 = comma_r1371( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3316:
        POPSTACKTRACE( EMPTYLIST );
}

DEFSTRING( t3341, "RH2 [inside RENUMBER]", 21 );

TSCP  comma_r1372( p1419 )
        TSCP  p1419;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3341 ) ) );
        if  ( EQ( TSCPTAG( p1419 ), PAIRTAG ) )  goto  L3344;
        scrt1__24__car_2derror( p1419 );
L3344:
        X3 = PAIR_CAR( p1419 );
        X4 = BOOLEAN( EQ( TSCPTAG( X3 ), FIXNUMTAG ) );
        if  ( TRUE( X4 ) )  goto  L3351;
        if  ( AND( EQ( TSCPTAG( X3 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X3 ), FLOATTAG ) ) )  goto  L3351;
        X2 = X3;
        goto L3356;
L3351:
        if  ( BITAND( BITOR( INT( DISPLAY( 0 ) ), 
                             INT( X3 ) ), 
                      3 ) )  goto  L3355;
        X2 = _TSCP( IPLUS( INT( DISPLAY( 0 ) ), 
                           INT( X3 ) ) );
        goto L3356;
L3355:
        X2 = scrt2__2b_2dtwo( DISPLAY( 0 ), X3 );
L3356:
        X5 = PAIR_CDR( p1419 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3359;
        scrt1__24__car_2derror( X5 );
L3359:
        X4 = PAIR_CAR( X5 );
        X3 = sc_cons( X4, EMPTYLIST );
        X1 = sc_cons( X2, X3 );
        POPSTACKTRACE( X1 );
}

EXTERNTSCPP( comma_r1372 );

TSCP  comma_renumber( n1368, r1369 )
        TSCP  n1368, r1369;
{
        TSCP  X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3311 ) ) );
        DISPLAY( 0 ) = n1368;
        if  ( EQ( TSCPTAG( r1369 ), PAIRTAG ) )  goto  L3363;
        scrt1__24__car_2derror( r1369 );
L3363:
        X4 = PAIR_CAR( r1369 );
        X3 = comma_r1372( X4 );
        X7 = PAIR_CDR( r1369 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3367;
        scrt1__24__car_2derror( X7 );
L3367:
        X6 = PAIR_CAR( X7 );
        X5 = comma_r1372( X6 );
        X8 = scrt1_caddr( r1369 );
        X7 = comma_r1372( X8 );
        X10 = scrt1_cadddr( r1369 );
        X9 = comma_r1372( X10 );
        X8 = sc_cons( X9, EMPTYLIST );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
        X2 = comma_r1371( r1369 );
        SDVAL = scrt1_append_2dtwo( X1, X2 );
        DISPLAY( 0 ) = SD0;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_construct_21_v );
DEFSTRING( t3370, "CONSTRUCT!", 10 );
EXTERNTSCPP( scrt6_error );
EXTERNTSCP( scrt6_error_v );

TSCP  comma_construct_21( c1472, p1473, r1474 )
        TSCP  c1472, p1473, r1474;
{
        TSCP  X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3370 ) ) );
        if  ( EQ( TSCPTAG( p1473 ), PAIRTAG ) )  goto  L3374;
        scrt1__24__cdr_2derror( p1473 );
L3374:
        X1 = PAIR_CDR( p1473 );
        if  ( NEQ( UNSIGNED( c1472 ), UNSIGNED( c1252 ) ) )  goto  L3376;
        X3 = PAIR_CAR( p1473 );
        if  ( EQ( TSCPTAG( r1474 ), PAIRTAG ) )  goto  L3380;
        scrt1__24__cdr_2derror( r1474 );
L3380:
        X4 = PAIR_CDR( r1474 );
        X2 = sc_cons( X3, X4 );
        goto L3404;
L3376:
        if  ( NEQ( UNSIGNED( c1472 ), UNSIGNED( c1099 ) ) )  goto  L3382;
        if  ( EQ( TSCPTAG( r1474 ), PAIRTAG ) )  goto  L3385;
        scrt1__24__car_2derror( r1474 );
L3385:
        X3 = PAIR_CAR( r1474 );
        X5 = PAIR_CAR( p1473 );
        X7 = PAIR_CDR( r1474 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3390;
        scrt1__24__cdr_2derror( X7 );
L3390:
        X6 = PAIR_CDR( X7 );
        X4 = sc_cons( X5, X6 );
        X2 = sc_cons( X3, X4 );
        goto L3404;
L3382:
        if  ( NEQ( UNSIGNED( c1472 ), UNSIGNED( c1259 ) ) )  goto  L3392;
        if  ( EQ( TSCPTAG( r1474 ), PAIRTAG ) )  goto  L3395;
        scrt1__24__car_2derror( r1474 );
L3395:
        X5 = PAIR_CAR( r1474 );
        X8 = PAIR_CDR( r1474 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto  L3399;
        scrt1__24__car_2derror( X8 );
L3399:
        X7 = PAIR_CAR( X8 );
        X6 = sc_cons( X7, EMPTYLIST );
        X4 = sc_cons( X5, X6 );
        X3 = X4;
        X5 = PAIR_CAR( p1473 );
        X6 = scrt1_cdddr( r1474 );
        X4 = sc_cons( X5, X6 );
        X2 = scrt1_append_2dtwo( X3, X4 );
        goto L3404;
L3392:
        if  ( NEQ( UNSIGNED( c1472 ), UNSIGNED( c1097 ) ) )  goto  L3403;
        if  ( EQ( TSCPTAG( r1474 ), PAIRTAG ) )  goto  L3406;
        scrt1__24__car_2derror( r1474 );
L3406:
        X5 = PAIR_CAR( r1474 );
        X8 = PAIR_CDR( r1474 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto  L3410;
        scrt1__24__car_2derror( X8 );
L3410:
        X7 = PAIR_CAR( X8 );
        X9 = scrt1_caddr( r1474 );
        X8 = sc_cons( X9, EMPTYLIST );
        X6 = sc_cons( X7, X8 );
        X4 = sc_cons( X5, X6 );
        X3 = X4;
        X5 = PAIR_CAR( p1473 );
        X6 = scrt1_cddddr( r1474 );
        X4 = sc_cons( X5, X6 );
        X2 = scrt1_append_2dtwo( X3, X4 );
        goto L3404;
L3403:
        X2 = FALSEVALUE;
L3404:
        X4 = PAIR_CAR( p1473 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3416;
        scrt1__24__car_2derror( X4 );
L3416:
        X3 = PAIR_CAR( X4 );
        X4 = scrt1_cadar( p1473 );
L3418:
        if  ( EQ( UNSIGNED( X1 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3419;
        if  ( NEQ( UNSIGNED( X4 ), UNSIGNED( c1104 ) ) )  goto  L3422;
        X5 = comma_over_2dknot_2dcell( X3, X2 );
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3426;
        scrt1__24__car_2derror( X1 );
L3426:
        X7 = PAIR_CAR( X1 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3429;
        scrt1__24__car_2derror( X7 );
L3429:
        X6 = PAIR_CAR( X7 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3432;
        scrt6_error( c1497, c1498, CONS( X5, EMPTYLIST ) );
L3432:
        SETGEN( PAIR_CAR( X5 ), X6 );
        X5 = comma_over_2dpos_2dcell( X3, X2 );
        X6 = scrt1_cadar( X1 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3435;
        scrt6_error( c1497, c1498, CONS( X5, EMPTYLIST ) );
L3435:
        SETGEN( PAIR_CAR( X5 ), X6 );
        goto L3423;
L3422:
        X5 = comma_under_2dknot_2dcell( X3, X2 );
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3439;
        scrt1__24__car_2derror( X1 );
L3439:
        X7 = PAIR_CAR( X1 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3442;
        scrt1__24__car_2derror( X7 );
L3442:
        X6 = PAIR_CAR( X7 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3445;
        scrt6_error( c1497, c1498, CONS( X5, EMPTYLIST ) );
L3445:
        SETGEN( PAIR_CAR( X5 ), X6 );
        X5 = comma_under_2dpos_2dcell( X3, X2 );
        X6 = scrt1_cadar( X1 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3448;
        scrt6_error( c1497, c1498, CONS( X5, EMPTYLIST ) );
L3448:
        SETGEN( PAIR_CAR( X5 ), X6 );
L3423:
        X5 = PAIR_CDR( X1 );
        X7 = PAIR_CAR( X1 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3453;
        scrt1__24__car_2derror( X7 );
L3453:
        X6 = PAIR_CAR( X7 );
        X4 = scrt1_cadar( X1 );
        X3 = X6;
        X1 = X5;
        goto L3418;
L3419:
        POPSTACKTRACE( X2 );
}

DEFTSCP( comma_make_2dpath_v );
DEFSTRING( t3455, "MAKE-PATH", 9 );
DEFSTRING( t3458, "comma_l1645 [inside MAKE-PATH]", 30 );
DEFSTRING( t3461, "MAKE-PATH-HELPER [inside MAKE-PATH]", 35 );
EXTERNTSCPP( comma_m1648 );

TSCP  comma_m1648( r1650, f1651, p1652 )
        TSCP  r1650, f1651, p1652;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3461 ) ) );
        if  ( NEQ( UNSIGNED( f1651 ), UNSIGNED( c1098 ) ) )  goto  L3463;
        X1 = DISPLAY( 2 );
        X1 = UNKNOWNCALL( X1, 1 );
        POPSTACKTRACE( VIA( PROCEDURE_CODE( X1 ) )( EMPTYLIST, 
                                                    PROCEDURE_CLOSURE( X1 ) ) );
L3463:
        if  ( AND( EQ( TSCPTAG( f1651 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( f1651 ), SYMBOLTAG ) )
            )  goto  L3465;
        if  ( NEQ( UNSIGNED( p1652 ), UNSIGNED( c1104 ) ) )  goto  L3467;
        X2 = comma_over_2dpos_v;
        X2 = UNKNOWNCALL( X2, 2 );
        X1 = VIA( PROCEDURE_CODE( X2 ) )( f1651, 
                                          r1650, 
                                          PROCEDURE_CLOSURE( X2 ) );
        goto L3468;
L3467:
        X2 = comma_under_2dpos_v;
        X2 = UNKNOWNCALL( X2, 2 );
        X1 = VIA( PROCEDURE_CODE( X2 ) )( f1651, 
                                          r1650, 
                                          PROCEDURE_CLOSURE( X2 ) );
L3468:
        if  ( NEQ( UNSIGNED( p1652 ), UNSIGNED( c1104 ) ) )  goto  L3469;
        X3 = comma_over_2dknot_v;
        X3 = UNKNOWNCALL( X3, 2 );
        X2 = VIA( PROCEDURE_CODE( X3 ) )( f1651, 
                                          r1650, 
                                          PROCEDURE_CLOSURE( X3 ) );
        goto L3470;
L3469:
        X3 = comma_under_2dknot_v;
        X3 = UNKNOWNCALL( X3, 2 );
        X2 = VIA( PROCEDURE_CODE( X3 ) )( f1651, 
                                          r1650, 
                                          PROCEDURE_CLOSURE( X3 ) );
L3470:
        X5 = sc_cons( X1, EMPTYLIST );
        X4 = sc_cons( X2, X5 );
        X3 = X4;
        X4 = comma_m1648( r1650, X2, X1 );
        POPSTACKTRACE( sc_cons( X3, X4 ) );
L3465:
        POPSTACKTRACE( EMPTYLIST );
}

TSCP  comma_l1645( a1646, c3457 )
        TSCP  a1646, c3457;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;
        TSCP  SD2 = DISPLAY( 2 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3458 ) ) );
        X1 = DISPLAY( 1 );
        DISPLAY( 1 ) = CLOSURE_VAR( c3457, 0 );
        X2 = DISPLAY( 0 );
        DISPLAY( 0 ) = CLOSURE_VAR( c3457, 1 );
        DISPLAY( 2 ) = a1646;
        if  ( NEQ( UNSIGNED( DISPLAY( 0 ) ), 
                   UNSIGNED( c1252 ) ) )  goto  L3473;
        X5 = DISPLAY( 1 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3476;
        scrt1__24__car_2derror( X5 );
L3476:
        X4 = PAIR_CAR( X5 );
        X7 = comma_nw_2dknot_v;
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X7 ) );
        X8 = comma_nw_2dpos_v;
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X8 ) );
        X5 = comma_m1648( DISPLAY( 1 ), X6, X7 );
        X3 = sc_cons( X4, X5 );
        goto L3490;
L3473:
        if  ( NEQ( UNSIGNED( DISPLAY( 0 ) ), 
                   UNSIGNED( c1099 ) ) )  goto  L3478;
        X5 = DISPLAY( 1 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3482;
        scrt1__24__cdr_2derror( X5 );
L3482:
        X6 = PAIR_CDR( X5 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3485;
        scrt1__24__car_2derror( X6 );
L3485:
        X4 = PAIR_CAR( X6 );
        X7 = comma_ne_2dknot_v;
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X7 ) );
        X8 = comma_ne_2dpos_v;
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X8 ) );
        X5 = comma_m1648( DISPLAY( 1 ), X6, X7 );
        X3 = sc_cons( X4, X5 );
        goto L3490;
L3478:
        if  ( NEQ( UNSIGNED( DISPLAY( 0 ) ), 
                   UNSIGNED( c1259 ) ) )  goto  L3487;
        X4 = scrt1_caddr( DISPLAY( 1 ) );
        X7 = comma_sw_2dknot_v;
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X7 ) );
        X8 = comma_sw_2dpos_v;
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X8 ) );
        X5 = comma_m1648( DISPLAY( 1 ), X6, X7 );
        X3 = sc_cons( X4, X5 );
        goto L3490;
L3487:
        if  ( NEQ( UNSIGNED( DISPLAY( 0 ) ), 
                   UNSIGNED( c1097 ) ) )  goto  L3489;
        X4 = scrt1_cadddr( DISPLAY( 1 ) );
        X7 = comma_se_2dknot_v;
        X7 = UNKNOWNCALL( X7, 1 );
        X6 = VIA( PROCEDURE_CODE( X7 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X7 ) );
        X8 = comma_se_2dpos_v;
        X8 = UNKNOWNCALL( X8, 1 );
        X7 = VIA( PROCEDURE_CODE( X8 ) )( DISPLAY( 1 ), 
                                          PROCEDURE_CLOSURE( X8 ) );
        X5 = comma_m1648( DISPLAY( 1 ), X6, X7 );
        X3 = sc_cons( X4, X5 );
        goto L3490;
L3489:
        X3 = FALSEVALUE;
L3490:
        DISPLAY( 1 ) = X1;
        DISPLAY( 0 ) = X2;
        SDVAL = X3;
        DISPLAY( 2 ) = SD2;
        POPSTACKTRACE( SDVAL );
}

TSCP  comma_make_2dpath( c1643, r1644 )
        TSCP  c1643, r1644;
{
        TSCP  X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SD1 = DISPLAY( 1 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3455 ) ) );
        DISPLAY( 0 ) = c1643;
        DISPLAY( 1 ) = r1644;
        X2 = MAKEPROCEDURE( 1, 
                            0, 
                            comma_l1645, 
                            MAKECLOSURE( EMPTYLIST, 
                                         2, 
                                         DISPLAY( 1 ), 
                                         DISPLAY( 0 ) ) );
        X1 = comma_call_2fcc_v;
        X1 = UNKNOWNCALL( X1, 1 );
        SDVAL = VIA( PROCEDURE_CODE( X1 ) )( X2, 
                                             PROCEDURE_CLOSURE( X1 ) );
        DISPLAY( 0 ) = SD0;
        DISPLAY( 1 ) = SD1;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_reverse_2dpath_v );
DEFSTRING( t3491, "REVERSE-PATH", 12 );
EXTERNTSCPP( scrt1_reverse );
EXTERNTSCP( scrt1_reverse_v );

TSCP  comma_reverse_2dpath( s1697, p1698 )
        TSCP  s1697, p1698;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3491 ) ) );
        X1 = scrt1_reverse( p1698 );
        X6 = sc_cons( c1098, EMPTYLIST );
        X5 = sc_cons( s1697, X6 );
        X4 = X5;
        X3 = sc_cons( X4, EMPTYLIST );
        X2 = X3;
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
}

DEFTSCP( comma_sum_v );
DEFSTRING( t3495, "SUM", 3 );
DEFSTRING( t3498, "REPLACE [inside SUM]", 20 );
EXTERNTSCPP( scrt1_length );
EXTERNTSCP( scrt1_length_v );
EXTERNTSCPP( comma_s1709 );
EXTERNTSCPP( comma_r1708 );

TSCP  comma_r1708( n1711, d1712, d1713 )
        TSCP  n1711, d1712, d1713;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3498 ) ) );
        if  ( EQ( UNSIGNED( d1712 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3500;
        if  ( EQ( TSCPTAG( d1712 ), PAIRTAG ) )  goto  L3503;
        scrt1__24__car_2derror( d1712 );
L3503:
        X2 = PAIR_CAR( d1712 );
        X1 = scrt1_length( X2 );
        if  ( EQ( TSCPTAG( X1 ), FIXNUMTAG ) )  goto  L3506;
        scrt6_error( c1723, c1724, CONS( X1, EMPTYLIST ) );
L3506:
        if  ( BITAND( INT( X1 ), 4 ) )  goto  L3508;
        X3 = PAIR_CAR( d1712 );
        X2 = comma_s1709( n1711, X3, d1713 );
        X4 = PAIR_CDR( d1712 );
        X3 = comma_r1708( n1711, X4, d1713 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L3508:
        X4 = PAIR_CAR( d1712 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3514;
        scrt1__24__car_2derror( X4 );
L3514:
        X3 = PAIR_CAR( X4 );
        X6 = PAIR_CAR( d1712 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3518;
        scrt1__24__cdr_2derror( X6 );
L3518:
        X5 = PAIR_CDR( X6 );
        X4 = comma_s1709( n1711, X5, d1713 );
        X2 = sc_cons( X3, X4 );
        X4 = PAIR_CDR( d1712 );
        X3 = comma_r1708( n1711, X4, d1713 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L3500:
        POPSTACKTRACE( EMPTYLIST );
}

DEFSTRING( t3521, "SINGLE-REPLACE [inside SUM]", 27 );

TSCP  comma_s1709( n1762, s1763, d1764 )
        TSCP  n1762, s1763, d1764;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3521 ) ) );
        if  ( BITAND( BITOR( INT( n1762 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3524;
        if  ( EQ( UNSIGNED( n1762 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3528;
        goto L3529;
L3524:
        if  ( FALSE( scrt2__3d_2dtwo( n1762, _TSCP( 4 ) ) ) )  goto  L3529;
L3528:
        if  ( EQ( UNSIGNED( s1763 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3532;
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3537;
        scrt1__24__car_2derror( s1763 );
L3537:
        X2 = PAIR_CAR( s1763 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1099 ) ) )  goto  L3534;
        if  ( EQ( TSCPTAG( d1764 ), PAIRTAG ) )  goto  L3540;
        scrt1__24__car_2derror( d1764 );
L3540:
        X1 = PAIR_CAR( d1764 );
        goto L3543;
L3534:
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3545;
        scrt1__24__car_2derror( s1763 );
L3545:
        X2 = PAIR_CAR( s1763 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1097 ) ) )  goto  L3542;
        X1 = scrt1_caddr( d1764 );
        goto L3543;
L3542:
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3548;
        scrt1__24__car_2derror( s1763 );
L3548:
        X3 = PAIR_CAR( s1763 );
        X6 = PAIR_CDR( s1763 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3552;
        scrt1__24__car_2derror( X6 );
L3552:
        X5 = PAIR_CAR( X6 );
        X4 = sc_cons( X5, EMPTYLIST );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
L3543:
        X4 = PAIR_CDR( s1763 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3557;
        scrt1__24__cdr_2derror( X4 );
L3557:
        X3 = PAIR_CDR( X4 );
        X2 = comma_s1709( n1762, X3, d1764 );
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
L3532:
        POPSTACKTRACE( EMPTYLIST );
L3529:
        if  ( EQ( UNSIGNED( s1763 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3559;
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3564;
        scrt1__24__car_2derror( s1763 );
L3564:
        X2 = PAIR_CAR( s1763 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1252 ) ) )  goto  L3561;
        if  ( EQ( TSCPTAG( d1764 ), PAIRTAG ) )  goto  L3567;
        scrt1__24__cdr_2derror( d1764 );
L3567:
        X2 = PAIR_CDR( d1764 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3570;
        scrt1__24__car_2derror( X2 );
L3570:
        X1 = PAIR_CAR( X2 );
        goto L3573;
L3561:
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3575;
        scrt1__24__car_2derror( s1763 );
L3575:
        X2 = PAIR_CAR( s1763 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1259 ) ) )  goto  L3572;
        X1 = scrt1_cadddr( d1764 );
        goto L3573;
L3572:
        if  ( EQ( TSCPTAG( s1763 ), PAIRTAG ) )  goto  L3578;
        scrt1__24__car_2derror( s1763 );
L3578:
        X3 = PAIR_CAR( s1763 );
        X6 = PAIR_CDR( s1763 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3582;
        scrt1__24__car_2derror( X6 );
L3582:
        X5 = PAIR_CAR( X6 );
        X4 = sc_cons( X5, EMPTYLIST );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
L3573:
        X4 = PAIR_CDR( s1763 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3587;
        scrt1__24__cdr_2derror( X4 );
L3587:
        X3 = PAIR_CDR( X4 );
        X2 = comma_s1709( n1762, X3, d1764 );
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
L3559:
        POPSTACKTRACE( EMPTYLIST );
}

EXTERNTSCPP( comma_direct_2dreps );
EXTERNTSCP( comma_direct_2dreps_v );

TSCP  comma_sum( r1705, r1706 )
        TSCP  r1705, r1706;
{
        TSCP  X16, 
              X15, 
              X14, 
              X13, 
              X12, 
              X11, 
              X10, 
              X9, 
              X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3495 ) ) );
        X1 = comma_direct_2dreps( r1705, r1706 );
        if  ( EQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3591;
        scrt1__24__car_2derror( X1 );
L3591:
        X2 = PAIR_CAR( X1 );
        X4 = PAIR_CDR( X1 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3596;
        scrt1__24__car_2derror( X4 );
L3596:
        X3 = PAIR_CAR( X4 );
        X6 = scrt1_length( r1705 );
        if  ( BITAND( BITOR( INT( X6 ), INT( _TSCP( 16 ) ) ), 
                      3 ) )  goto  L3600;
        X5 = _TSCP( IDIFFERENCE( INT( X6 ), 
                                 INT( _TSCP( 16 ) ) ) );
        goto L3601;
L3600:
        X5 = scrt2__2d_2dtwo( X6, _TSCP( 16 ) );
L3601:
        X4 = comma_renumber( X5, X3 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3604;
        scrt1__24__car_2derror( X2 );
L3604:
        X9 = PAIR_CAR( X2 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3607;
        scrt1__24__cdr_2derror( X4 );
L3607:
        X13 = PAIR_CDR( X4 );
        if  ( EQ( TSCPTAG( X13 ), PAIRTAG ) )  goto  L3610;
        scrt1__24__car_2derror( X13 );
L3610:
        X12 = PAIR_CAR( X13 );
        X11 = comma_s1709( _TSCP( 8 ), X12, X2 );
        X13 = scrt1_caddr( X2 );
        X16 = scrt1_cadddr( X4 );
        X15 = comma_s1709( _TSCP( 8 ), X16, X2 );
        X14 = sc_cons( X15, EMPTYLIST );
        X12 = sc_cons( X13, X14 );
        X10 = sc_cons( X11, X12 );
        X8 = sc_cons( X9, X10 );
        X7 = X8;
        X8 = scrt1_cddddr( X2 );
        X6 = scrt1_append_2dtwo( X7, X8 );
        X5 = comma_r1708( _TSCP( 4 ), X6, X4 );
        X7 = scrt1_cddddr( X4 );
        X6 = comma_r1708( _TSCP( 8 ), X7, X2 );
        POPSTACKTRACE( scrt1_append_2dtwo( X5, X6 ) );
}

DEFTSCP( comma_direct_2dreps_v );
DEFSTRING( t3613, "DIRECT-REPS", 11 );
EXTERNTSCPP( comma_connected_3f );
EXTERNTSCP( comma_connected_3f_v );
EXTERNTSCPP( comma_ted_2dreps_ec8f8b13 );
EXTERNTSCP( comma_ted_2dreps_ec8f8b13_v );
EXTERNTSCPP( comma_direct_2d2nc_2dreps );
EXTERNTSCP( comma_direct_2d2nc_2dreps_v );
EXTERNTSCPP( comma_direct_2d1nc_2dreps );
EXTERNTSCP( comma_direct_2d1nc_2dreps_v );

TSCP  comma_direct_2dreps( r1926, r1927 )
        TSCP  r1926, r1927;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t3613 ) ) );
        X1 = comma_connected_3f( r1926 );
        if  ( FALSE( X1 ) )  goto  L3621;
        if  ( FALSE( comma_connected_3f( r1927 ) ) )  goto  L3621;
        POPSTACKTRACE( comma_ted_2dreps_ec8f8b13( r1926, r1927 ) );
L3621:
        if  ( FALSE( comma_connected_3f( r1926 ) ) )  goto  L3622;
        POPSTACKTRACE( comma_direct_2d2nc_2dreps( r1926, r1927 ) );
L3622:
        POPSTACKTRACE( comma_direct_2d1nc_2dreps( r1926, r1927 ) );
}

DEFTSCP( comma_connected_3f_v );
DEFSTRING( t3624, "CONNECTED?", 10 );

TSCP  comma_connected_3f( r1937 )
        TSCP  r1937;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3624 ) ) );
        X1 = comma_make_2dpath( c1097, r1937 );
        X2 = comma_make_2dpath( c1099, r1937 );
        if  ( FALSE( X2 ) )  goto  L3627;
        X3 = FALSEVALUE;
        goto L3628;
L3627:
        X3 = TRUEVALUE;
L3628:
        if  ( FALSE( X3 ) )  goto  L3635;
        if  ( TRUE( X1 ) )  goto  L3635;
        POPSTACKTRACE( EMPTYLIST );
L3635:
        if  ( FALSE( X2 ) )  goto  L3636;
        X4 = scrt1_reverse( X2 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3640;
        scrt1__24__car_2derror( X4 );
L3640:
        X5 = PAIR_CAR( X4 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3643;
        scrt1__24__car_2derror( X5 );
L3643:
        X3 = PAIR_CAR( X5 );
        POPSTACKTRACE( BOOLEAN( EQ( UNSIGNED( X3 ), 
                                    UNSIGNED( c1097 ) ) ) );
L3636:
        X4 = scrt1_reverse( X1 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3647;
        scrt1__24__car_2derror( X4 );
L3647:
        X5 = PAIR_CAR( X4 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3650;
        scrt1__24__car_2derror( X5 );
L3650:
        X3 = PAIR_CAR( X5 );
        POPSTACKTRACE( BOOLEAN( EQ( UNSIGNED( X3 ), 
                                    UNSIGNED( c1099 ) ) ) );
}

DEFTSCP( comma_ted_2dreps_ec8f8b13_v );
DEFSTRING( t3652, "DIRECT-CONNECTED-REPS", 21 );
EXTERNTSCPP( comma_boolean_3d_3f );
EXTERNTSCP( comma_boolean_3d_3f_v );
EXTERNTSCPP( comma_reverse_2dstrand );
EXTERNTSCP( comma_reverse_2dstrand_v );

TSCP  comma_ted_2dreps_ec8f8b13( r1972, r1973 )
        TSCP  r1972, r1973;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3652 ) ) );
        X1 = comma_make_2dpath( c1099, r1972 );
        X2 = comma_make_2dpath( c1252, r1973 );
        if  ( FALSE( comma_boolean_3d_3f( X1, X2 ) ) )  goto  L3654;
        X3 = comma_reverse_2dstrand( c1252, r1973 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( r1972, X2 );
        POPSTACKTRACE( X1 );
L3654:
        X2 = sc_cons( r1973, EMPTYLIST );
        X1 = sc_cons( r1972, X2 );
        POPSTACKTRACE( X1 );
}

DEFTSCP( comma_direct_2d1nc_2dreps_v );
DEFSTRING( t3658, "DIRECT-1NC-REPS", 15 );

TSCP  comma_direct_2d1nc_2dreps( r1981, r1982 )
        TSCP  r1981, r1982;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3658 ) ) );
        X3 = comma_make_2dpath( c1252, r1982 );
        X4 = comma_make_2dpath( c1099, r1981 );
        if  ( FALSE( comma_boolean_3d_3f( X3, X4 ) ) )  goto  L3660;
        X3 = comma_make_2dpath( c1259, r1982 );
        X4 = comma_make_2dpath( c1097, r1981 );
        if  ( FALSE( comma_boolean_3d_3f( X3, X4 ) ) )  goto  L3662;
        X3 = comma_reverse_2dstrand( c1097, r1981 );
        X2 = comma_reverse_2dstrand( c1099, X3 );
        goto L3665;
L3662:
        X2 = comma_reverse_2dstrand( c1099, r1981 );
        goto L3665;
L3660:
        X3 = comma_make_2dpath( c1259, r1982 );
        X4 = comma_make_2dpath( c1097, r1981 );
        if  ( FALSE( comma_boolean_3d_3f( X3, X4 ) ) )  goto  L3664;
        X2 = comma_reverse_2dstrand( c1097, r1981 );
        goto L3665;
L3664:
        X2 = r1981;
L3665:
        X3 = sc_cons( r1982, EMPTYLIST );
        X1 = sc_cons( X2, X3 );
        POPSTACKTRACE( X1 );
}

DEFTSCP( comma_direct_2d2nc_2dreps_v );
DEFSTRING( t3667, "DIRECT-2NC-REPS", 15 );

TSCP  comma_direct_2d2nc_2dreps( r1986, r1987 )
        TSCP  r1986, r1987;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3667 ) ) );
        X4 = comma_make_2dpath( c1252, r1987 );
        X5 = comma_make_2dpath( c1099, r1986 );
        if  ( FALSE( comma_boolean_3d_3f( X4, X5 ) ) )  goto  L3669;
        X4 = comma_make_2dpath( c1259, r1987 );
        X5 = comma_make_2dpath( c1097, r1986 );
        if  ( FALSE( comma_boolean_3d_3f( X4, X5 ) ) )  goto  L3671;
        X4 = comma_reverse_2dstrand( c1259, r1987 );
        X3 = comma_reverse_2dstrand( c1252, X4 );
        goto L3674;
L3671:
        X3 = comma_reverse_2dstrand( c1252, r1987 );
        goto L3674;
L3669:
        X4 = comma_make_2dpath( c1259, r1987 );
        X5 = comma_make_2dpath( c1097, r1986 );
        if  ( FALSE( comma_boolean_3d_3f( X4, X5 ) ) )  goto  L3673;
        X3 = comma_reverse_2dstrand( c1259, r1987 );
        goto L3674;
L3673:
        X3 = r1987;
L3674:
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = sc_cons( r1986, X2 );
        POPSTACKTRACE( X1 );
}

DEFTSCP( comma_opposite_2dend_v );
DEFSTRING( t3676, "OPPOSITE-END", 12 );
EXTERNTSCPP( comma_delq );
EXTERNTSCP( comma_delq_v );

TSCP  comma_opposite_2dend( c1992, r1993 )
        TSCP  c1992, r1993;
{
        TSCP  X8, X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3676 ) ) );
        X1 = c1992;
        X2 = r1993;
        X8 = sc_cons( c1097, EMPTYLIST );
        X7 = sc_cons( c1259, X8 );
        X6 = sc_cons( c1099, X7 );
        X5 = sc_cons( c1252, X6 );
        X4 = X5;
        X3 = comma_delq( c1992, X4 );
L3680:
        if  ( NEQ( UNSIGNED( X3 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3681;
        X5 = comma_make_2dpath( X1, X2 );
        X4 = scrt1_reverse( X5 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3685;
        scrt1__24__car_2derror( X4 );
L3685:
        X5 = PAIR_CAR( X4 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3688;
        scrt1__24__car_2derror( X5 );
L3688:
        POPSTACKTRACE( PAIR_CAR( X5 ) );
L3681:
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L3691;
        scrt1__24__car_2derror( X3 );
L3691:
        X5 = PAIR_CAR( X3 );
        X4 = comma_make_2dpath( X5, X2 );
        X5 = BOOLEAN( EQ( UNSIGNED( X4 ), 
                          UNSIGNED( EMPTYLIST ) ) );
        if  ( TRUE( X5 ) )  goto  L3698;
        X7 = scrt1_reverse( X4 );
        if  ( EQ( TSCPTAG( X7 ), PAIRTAG ) )  goto  L3703;
        scrt1__24__car_2derror( X7 );
L3703:
        X8 = PAIR_CAR( X7 );
        if  ( EQ( TSCPTAG( X8 ), PAIRTAG ) )  goto  L3706;
        scrt1__24__car_2derror( X8 );
L3706:
        X6 = PAIR_CAR( X8 );
        if  ( NEQ( UNSIGNED( X6 ), UNSIGNED( X1 ) ) )  goto  L3698;
        POPSTACKTRACE( PAIR_CAR( X3 ) );
L3698:
        X3 = PAIR_CDR( X3 );
        goto L3680;
}

DEFTSCP( comma_reverse_2dstrand_v );
DEFSTRING( t3710, "REVERSE-STRAND", 14 );
EXTERNTSCPP( comma_reverse_2ddirections_21 );
EXTERNTSCP( comma_reverse_2ddirections_21_v );
EXTERNTSCPP( comma_change_2dorigin );
EXTERNTSCP( comma_change_2dorigin_v );
EXTERNTSCPP( comma_junkate );
EXTERNTSCP( comma_junkate_v );

TSCP  comma_reverse_2dstrand( c2055, r2056 )
        TSCP  c2055, r2056;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3710 ) ) );
        X1 = comma_newlist( r2056 );
        if  ( FALSE( comma_make_2dpath( c2055, X1 ) ) )  goto  L3713;
        X2 = c2055;
        goto L3714;
L3713:
        X2 = comma_opposite_2dend( c2055, X1 );
L3714:
        X4 = comma_make_2dpath( X2, X1 );
        X3 = comma_reverse_2dpath( X2, X4 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L3718;
        scrt1__24__cdr_2derror( X3 );
L3718:
        X4 = PAIR_CDR( X3 );
        X5 = comma_opposite_2dend( c2055, X1 );
        comma_construct_21( X5, X4, X1 );
        comma_reverse_2ddirections_21( X4, X1 );
        if  ( NEQ( UNSIGNED( c2055 ), UNSIGNED( X2 ) ) )  goto  L3723;
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3726;
        scrt1__24__car_2derror( X4 );
L3726:
        X6 = PAIR_CAR( X4 );
        X7 = comma_junkate( c2055, X1 );
        POPSTACKTRACE( comma_change_2dorigin( X5, X6, X7 ) );
L3723:
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3729;
        scrt1__24__car_2derror( X4 );
L3729:
        X6 = PAIR_CAR( X4 );
        X7 = comma_junkate( X5, X1 );
        POPSTACKTRACE( comma_change_2dorigin( c2055, X6, X7 ) );
}

DEFTSCP( comma_change_2dorigin_v );
DEFSTRING( t3731, "CHANGE-ORIGIN", 13 );
DEFSTRING( t3734, 
           "MAKE-LIST-OF-DIRECTIONS [inside CHANGE-ORIGIN]", 46 );
EXTERNTSCPP( comma_m2091 );

TSCP  comma_m2091( l2094 )
        TSCP  l2094;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3734 ) ) );
        if  ( EQ( TSCPTAG( l2094 ), PAIRTAG ) )  goto  L3739;
        scrt1__24__car_2derror( l2094 );
L3739:
        X1 = PAIR_CAR( l2094 );
        if  ( NEQ( UNSIGNED( X1 ), 
                   UNSIGNED( DISPLAY( 0 ) ) ) )  goto  L3736;
        X1 = PAIR_CDR( l2094 );
        POPSTACKTRACE( sc_cons( c1098, X1 ) );
L3736:
        if  ( EQ( TSCPTAG( l2094 ), PAIRTAG ) )  goto  L3743;
        scrt1__24__car_2derror( l2094 );
L3743:
        X1 = PAIR_CAR( l2094 );
        X3 = PAIR_CDR( l2094 );
        X2 = comma_m2091( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
}

DEFSTRING( t3746, "CONSTRUCT [inside CHANGE-ORIGIN]", 32 );
EXTERNTSCPP( comma_c2092 );

TSCP  comma_c2092( l2115, o2116 )
        TSCP  l2115, o2116;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3746 ) ) );
        if  ( EQ( UNSIGNED( l2115 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3748;
        if  ( EQ( TSCPTAG( l2115 ), PAIRTAG ) )  goto  L3753;
        scrt1__24__car_2derror( l2115 );
L3753:
        X1 = PAIR_CAR( l2115 );
        if  ( NEQ( UNSIGNED( X1 ), UNSIGNED( c1098 ) ) )  goto  L3750;
        X2 = PAIR_CDR( l2115 );
        if  ( EQ( TSCPTAG( o2116 ), PAIRTAG ) )  goto  L3757;
        scrt1__24__cdr_2derror( o2116 );
L3757:
        X3 = PAIR_CDR( o2116 );
        X1 = comma_c2092( X2, X3 );
        POPSTACKTRACE( sc_cons( DISPLAY( 1 ), X1 ) );
L3750:
        if  ( EQ( TSCPTAG( o2116 ), PAIRTAG ) )  goto  L3760;
        scrt1__24__car_2derror( o2116 );
L3760:
        X1 = PAIR_CAR( o2116 );
        if  ( EQ( TSCPTAG( l2115 ), PAIRTAG ) )  goto  L3763;
        scrt1__24__cdr_2derror( l2115 );
L3763:
        X3 = PAIR_CDR( l2115 );
        X4 = PAIR_CDR( o2116 );
        X2 = comma_c2092( X3, X4 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3748:
        POPSTACKTRACE( EMPTYLIST );
}

EXTERNTSCPP( comma_list_2dhead );
EXTERNTSCP( comma_list_2dhead_v );

TSCP  comma_change_2dorigin( c2087, n2088, r2089 )
        TSCP  c2087, n2088, r2089;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;
        TSCP  SD0 = DISPLAY( 0 );
        TSCP  SD1 = DISPLAY( 1 );
        TSCP  SDVAL;

        PUSHSTACKTRACE( U_TX( ADR( t3731 ) ) );
        DISPLAY( 0 ) = c2087;
        DISPLAY( 1 ) = n2088;
        X7 = sc_cons( c1097, EMPTYLIST );
        X6 = sc_cons( c1259, X7 );
        X5 = sc_cons( c1099, X6 );
        X4 = sc_cons( c1252, X5 );
        X3 = X4;
        X2 = comma_m2091( X3 );
        X3 = comma_list_2dhead( r2089, _TSCP( 16 ) );
        X1 = comma_c2092( X2, X3 );
        X2 = scrt1_cddddr( r2089 );
        SDVAL = scrt1_append_2dtwo( X1, X2 );
        DISPLAY( 0 ) = SD0;
        DISPLAY( 1 ) = SD1;
        POPSTACKTRACE( SDVAL );
}

DEFTSCP( comma_junkate_v );
DEFSTRING( t3767, "JUNKATE", 7 );

TSCP  comma_junkate( c2153, r2154 )
        TSCP  c2153, r2154;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3767 ) ) );
        X3 = sc_cons( c1098, EMPTYLIST );
        X2 = sc_cons( c1098, X3 );
        X1 = X2;
        POPSTACKTRACE( comma_change_2dorigin( c2153, X1, r2154 ) );
}

DEFTSCP( comma_reverse_2ddirections_21_v );
DEFSTRING( t3770, "REVERSE-DIRECTIONS!", 19 );

TSCP  comma_reverse_2ddirections_21( p2158, r2159 )
        TSCP  p2158, r2159;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3770 ) ) );
L3771:
        if  ( EQ( TSCPTAG( p2158 ), PAIRTAG ) )  goto  L3775;
        scrt1__24__car_2derror( p2158 );
L3775:
        X1 = PAIR_CAR( p2158 );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), SYMBOLTAG ) ) )  goto  L3772;
        X2 = PAIR_CAR( p2158 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3781;
        scrt1__24__car_2derror( X2 );
L3781:
        X1 = PAIR_CAR( X2 );
        if  ( AND( EQ( TSCPTAG( X1 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( X1 ), SYMBOLTAG ) ) )  goto  L3777;
        X5 = PAIR_CAR( p2158 );
        if  ( EQ( TSCPTAG( X5 ), PAIRTAG ) )  goto  L3788;
        scrt1__24__car_2derror( X5 );
L3788:
        X4 = PAIR_CAR( X5 );
        X3 = comma_row( X4, r2159 );
        if  ( EQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L3791;
        scrt1__24__car_2derror( X3 );
L3791:
        X2 = PAIR_CAR( X3 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c1113 ) ) )  goto  L3784;
        X1 = c1092;
        goto L3785;
L3784:
        X1 = c1113;
L3785:
        X4 = PAIR_CAR( p2158 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3795;
        scrt1__24__car_2derror( X4 );
L3795:
        X3 = PAIR_CAR( X4 );
        X2 = comma_row( X3, r2159 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L3798;
        scrt6_error( c1497, c1498, CONS( X2, EMPTYLIST ) );
L3798:
        SETGEN( PAIR_CAR( X2 ), X1 );
        X1 = PAIR_CDR( p2158 );
        p2158 = X1;
        goto L3771;
L3777:
        POPSTACKTRACE( r2159 );
L3772:
        POPSTACKTRACE( r2159 );
}

DEFTSCP( comma_mult_v );
DEFSTRING( t3801, "MULT", 4 );
DEFSTRING( t3804, "MULT-HELPER [inside MULT]", 25 );
EXTERNTSCPP( comma_m2223 );

TSCP  comma_m2223( l2225 )
        TSCP  l2225;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3804 ) ) );
        X1 = scrt1_length( l2225 );
        if  ( BITAND( BITOR( INT( _TSCP( 8 ) ), INT( X1 ) ), 
                      3 ) )  goto  L3808;
        if  ( EQ( UNSIGNED( _TSCP( 8 ) ), UNSIGNED( X1 ) ) )  goto  L3812;
        goto L3813;
L3808:
        if  ( FALSE( scrt2__3d_2dtwo( _TSCP( 8 ), X1 ) ) )  goto  L3813;
L3812:
        if  ( EQ( TSCPTAG( l2225 ), PAIRTAG ) )  goto  L3817;
        scrt1__24__car_2derror( l2225 );
L3817:
        X3 = PAIR_CAR( l2225 );
        X2 = comma_int_2d_3erep( X3 );
        X1 = comma_mult0( X2 );
        X4 = PAIR_CDR( l2225 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3821;
        scrt1__24__car_2derror( X4 );
L3821:
        X3 = PAIR_CAR( X4 );
        X2 = comma_int_2d_3erep( X3 );
        POPSTACKTRACE( comma_sum( X1, X2 ) );
L3813:
        X1 = scrt1_length( l2225 );
        if  ( BITAND( BITOR( INT( _TSCP( 4 ) ), INT( X1 ) ), 
                      3 ) )  goto  L3825;
        if  ( EQ( UNSIGNED( _TSCP( 4 ) ), UNSIGNED( X1 ) ) )  goto  L3829;
        goto L3830;
L3825:
        if  ( TRUE( scrt2__3d_2dtwo( _TSCP( 4 ), X1 ) ) )  goto  L3829;
L3830:
        X5 = scrt1_length( l2225 );
        X4 = comma_sub1( X5 );
        X3 = comma_list_2dhead( l2225, X4 );
        X2 = comma_m2223( X3 );
        X1 = comma_mult0( X2 );
        X4 = scrt1_reverse( l2225 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3834;
        scrt1__24__car_2derror( X4 );
L3834:
        X3 = PAIR_CAR( X4 );
        X2 = comma_int_2d_3erep( X3 );
        POPSTACKTRACE( comma_sum( X1, X2 ) );
L3829:
        if  ( EQ( TSCPTAG( l2225 ), PAIRTAG ) )  goto  L3837;
        scrt1__24__car_2derror( l2225 );
L3837:
        X1 = PAIR_CAR( l2225 );
        POPSTACKTRACE( comma_int_2d_3erep( X1 ) );
}

TSCP  comma_mult( n2221 )
        TSCP  n2221;
{
        PUSHSTACKTRACE( U_TX( ADR( t3801 ) ) );
        POPSTACKTRACE( comma_m2223( n2221 ) );
}

DEFTSCP( comma_expand_v );
DEFSTRING( t3839, "EXPAND", 6 );
EXTERNTSCPP( scrt2_quotient );
EXTERNTSCP( scrt2_quotient_v );
EXTERNTSCPP( comma_expand );
EXTERNTSCP( comma_expand_v );
EXTERNTSCPP( scrt2_remainder );
EXTERNTSCP( scrt2_remainder_v );

TSCP  comma_expand( m2268, n2269 )
        TSCP  m2268, n2269;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3839 ) ) );
        if  ( BITAND( BITOR( INT( m2268 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3842;
        if  ( EQ( UNSIGNED( m2268 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3846;
        goto L3847;
L3842:
        if  ( FALSE( scrt2__3d_2dtwo( m2268, _TSCP( 4 ) ) ) )  goto  L3847;
L3846:
        X1 = sc_cons( n2269, EMPTYLIST );
        POPSTACKTRACE( X1 );
L3847:
        if  ( BITAND( BITOR( INT( n2269 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3852;
        if  ( EQ( UNSIGNED( n2269 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3856;
        goto L3857;
L3852:
        if  ( TRUE( scrt2__3d_2dtwo( n2269, _TSCP( 4 ) ) ) )  goto  L3856;
L3857:
        if  ( BITAND( BITOR( INT( m2268 ), INT( n2269 ) ), 
                      3 ) )  goto  L3860;
        X1 = C_FIXED( QUOTIENT( INT( m2268 ), INT( n2269 ) ) );
        goto L3861;
L3860:
        X1 = scrt2_quotient( m2268, n2269 );
L3861:
        if  ( BITAND( BITOR( INT( m2268 ), INT( n2269 ) ), 
                      3 ) )  goto  L3862;
        X3 = _TSCP( REMAINDER( INT( m2268 ), INT( n2269 ) ) );
        goto L3863;
L3862:
        X3 = scrt2_remainder( m2268, n2269 );
L3863:
        X2 = comma_expand( n2269, X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3856:
        X1 = sc_cons( m2268, EMPTYLIST );
        POPSTACKTRACE( X1 );
}

DEFTSCP( comma_rat_2d_3erep_v );
DEFSTRING( t3865, "RAT->REP", 8 );
EXTERNTSCPP( sc_apply_2dtwo );
EXTERNTSCP( sc_apply_2dtwo_v );

TSCP  comma_rat_2d_3erep( m2306, n2307 )
        TSCP  m2306, n2307;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3865 ) ) );
        X2 = comma_expand( m2306, n2307 );
        X1 = scrt1_reverse( X2 );
        POPSTACKTRACE( sc_apply_2dtwo( comma_mult_v, X1 ) );
}

DEFTSCP( comma_series_v );
DEFSTRING( t3867, "SERIES", 6 );
DEFSTRING( t3870, "SERIES-HELPER [inside SERIES]", 29 );
EXTERNTSCPP( comma_s2312 );

TSCP  comma_s2312( s2314 )
        TSCP  s2314;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3870 ) ) );
        if  ( NEQ( UNSIGNED( s2314 ), 
                   UNSIGNED( EMPTYLIST ) ) )  goto  L3872;
        POPSTACKTRACE( comma_int_2d_3erep( _TSCP( 0 ) ) );
L3872:
        if  ( EQ( TSCPTAG( s2314 ), PAIRTAG ) )  goto  L3877;
        scrt1__24__car_2derror( s2314 );
L3877:
        X1 = PAIR_CAR( s2314 );
        if  ( NEQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3874;
        X3 = PAIR_CAR( s2314 );
        X2 = sc_apply_2dtwo( comma_mult_v, X3 );
        X1 = comma_mult0( X2 );
        X3 = PAIR_CDR( s2314 );
        X2 = comma_s2312( X3 );
        POPSTACKTRACE( comma_sum( X1, X2 ) );
L3874:
        if  ( EQ( TSCPTAG( s2314 ), PAIRTAG ) )  goto  L3882;
        scrt1__24__car_2derror( s2314 );
L3882:
        X3 = PAIR_CAR( s2314 );
        X2 = comma_int_2d_3erep( X3 );
        X1 = comma_mult0( X2 );
        X3 = PAIR_CDR( s2314 );
        X2 = comma_s2312( X3 );
        POPSTACKTRACE( comma_sum( X1, X2 ) );
}

TSCP  comma_series( s2310 )
        TSCP  s2310;
{
        PUSHSTACKTRACE( U_TX( ADR( t3867 ) ) );
        POPSTACKTRACE( comma_s2312( s2310 ) );
}

DEFTSCP( comma_connect_v );
DEFSTRING( t3885, "CONNECT", 7 );
DEFSTRING( t3888, "JOIN [inside CONNECT]", 21 );
EXTERNTSCPP( comma_r2347 );

TSCP  comma_j2346( c2350, c2351, r2352 )
        TSCP  c2350, c2351, r2352;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3888 ) ) );
        X2 = comma_make_2dpath( c2350, r2352 );
        X3 = comma_make_2dpath( c2351, r2352 );
        if  ( FALSE( comma_boolean_3d_3f( X2, X3 ) ) )  goto  L3890;
        X1 = comma_reverse_2dstrand( c2350, r2352 );
        goto L3891;
L3890:
        X1 = r2352;
L3891:
        X2 = comma_r2347( c2351, c2350, X1, X1 );
        POPSTACKTRACE( comma_r2347( c2350, c2351, X2, X1 ) );
}

DEFSTRING( t3893, "REPLACE [inside CONNECT]", 24 );
EXTERNTSCPP( comma_s2348 );

TSCP  comma_r2347( c2356, c2357, n2358, f2359 )
        TSCP  c2356, c2357, n2358, f2359;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3893 ) ) );
        if  ( EQ( UNSIGNED( n2358 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3895;
        if  ( EQ( TSCPTAG( n2358 ), PAIRTAG ) )  goto  L3898;
        scrt1__24__car_2derror( n2358 );
L3898:
        X2 = PAIR_CAR( n2358 );
        X1 = scrt1_length( X2 );
        if  ( EQ( TSCPTAG( X1 ), FIXNUMTAG ) )  goto  L3901;
        scrt6_error( c1723, c1724, CONS( X1, EMPTYLIST ) );
L3901:
        if  ( BITAND( INT( X1 ), 4 ) )  goto  L3903;
        X3 = PAIR_CAR( n2358 );
        X2 = comma_s2348( c2356, c2357, X3, f2359 );
        X4 = PAIR_CDR( n2358 );
        X3 = comma_r2347( c2356, c2357, X4, f2359 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L3903:
        X4 = PAIR_CAR( n2358 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3909;
        scrt1__24__car_2derror( X4 );
L3909:
        X3 = PAIR_CAR( X4 );
        X6 = PAIR_CAR( n2358 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3913;
        scrt1__24__cdr_2derror( X6 );
L3913:
        X5 = PAIR_CDR( X6 );
        X4 = comma_s2348( c2356, c2357, X5, f2359 );
        X2 = sc_cons( X3, X4 );
        X4 = PAIR_CDR( n2358 );
        X3 = comma_r2347( c2356, c2357, X4, f2359 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L3895:
        POPSTACKTRACE( EMPTYLIST );
}

DEFSTRING( t3916, "SINGLE-REPLACE [inside CONNECT]", 31 );

TSCP  comma_s2348( c2406, c2407, s2408, f2409 )
        TSCP  c2406, c2407, s2408, f2409;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3916 ) ) );
        if  ( EQ( UNSIGNED( s2408 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3918;
        if  ( EQ( TSCPTAG( s2408 ), PAIRTAG ) )  goto  L3923;
        scrt1__24__car_2derror( s2408 );
L3923:
        X2 = PAIR_CAR( s2408 );
        if  ( NEQ( UNSIGNED( X2 ), UNSIGNED( c2406 ) ) )  goto  L3920;
        X1 = comma_select_2dorigin( c2407, f2409 );
        goto L3921;
L3920:
        if  ( EQ( TSCPTAG( s2408 ), PAIRTAG ) )  goto  L3926;
        scrt1__24__car_2derror( s2408 );
L3926:
        X3 = PAIR_CAR( s2408 );
        X6 = PAIR_CDR( s2408 );
        if  ( EQ( TSCPTAG( X6 ), PAIRTAG ) )  goto  L3930;
        scrt1__24__car_2derror( X6 );
L3930:
        X5 = PAIR_CAR( X6 );
        X4 = sc_cons( X5, EMPTYLIST );
        X2 = sc_cons( X3, X4 );
        X1 = X2;
L3921:
        X4 = PAIR_CDR( s2408 );
        if  ( EQ( TSCPTAG( X4 ), PAIRTAG ) )  goto  L3935;
        scrt1__24__cdr_2derror( X4 );
L3935:
        X3 = PAIR_CDR( X4 );
        X2 = comma_s2348( c2406, c2407, X3, f2409 );
        POPSTACKTRACE( scrt1_append_2dtwo( X1, X2 ) );
L3918:
        POPSTACKTRACE( EMPTYLIST );
}

EXTERNTSCPP( comma_j2346 );

TSCP  comma_connect( r2344 )
        TSCP  r2344;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3885 ) ) );
        X2 = comma_j2346( c1259, c1097, r2344 );
        X1 = comma_j2346( c1252, c1099, X2 );
        POPSTACKTRACE( scrt1_cddddr( X1 ) );
}

DEFTSCP( comma_prepare_v );
DEFSTRING( t3937, "PREPARE", 7 );
EXTERNTSCPP( comma_replace_2dtext );
EXTERNTSCP( comma_replace_2dtext_v );
EXTERNTSCPP( comma_flesh_2dout );
EXTERNTSCP( comma_flesh_2dout_v );

TSCP  comma_prepare( r2450 )
        TSCP  r2450;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3937 ) ) );
        X6 = comma_renumber( _TSCP( 16 ), r2450 );
        X5 = comma_flesh_2dout( X6 );
        X4 = comma_replace_2dtext( c1098, _TSCP( 0 ), X5 );
        X3 = comma_replace_2dtext( c1097, _TSCP( 16 ), X4 );
        X2 = comma_replace_2dtext( c1259, _TSCP( 12 ), X3 );
        X1 = comma_replace_2dtext( c1099, _TSCP( 8 ), X2 );
        POPSTACKTRACE( comma_replace_2dtext( c1252, _TSCP( 4 ), X1 ) );
}

DEFTSCP( comma_flesh_2dout_v );
DEFSTRING( t3939, "FLESH-OUT", 9 );

TSCP  comma_flesh_2dout( r2455 )
        TSCP  r2455;
{
        TSCP  X7, X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3939 ) ) );
        if  ( EQ( UNSIGNED( r2455 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3941;
        if  ( EQ( TSCPTAG( r2455 ), PAIRTAG ) )  goto  L3944;
        scrt1__24__car_2derror( r2455 );
L3944:
        X2 = PAIR_CAR( r2455 );
        X1 = scrt1_length( X2 );
        if  ( BITAND( BITOR( INT( X1 ), INT( _TSCP( 8 ) ) ), 
                      3 ) )  goto  L3948;
        if  ( EQ( UNSIGNED( X1 ), UNSIGNED( _TSCP( 8 ) ) ) )  goto  L3952;
        goto L3953;
L3948:
        if  ( TRUE( scrt2__3d_2dtwo( X1, _TSCP( 8 ) ) ) )  goto  L3952;
        goto L3953;
L3941:
        POPSTACKTRACE( EMPTYLIST );
L3952:
        X3 = sc_cons( _TSCP( 0 ), EMPTYLIST );
        X2 = X3;
        X4 = PAIR_CAR( r2455 );
        X7 = sc_cons( _TSCP( 0 ), EMPTYLIST );
        X6 = sc_cons( _TSCP( 0 ), X7 );
        X5 = X6;
        X3 = scrt1_append_2dtwo( X4, X5 );
        X1 = scrt1_append_2dtwo( X2, X3 );
        X3 = PAIR_CDR( r2455 );
        X2 = comma_flesh_2dout( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3953:
        X1 = PAIR_CAR( r2455 );
        X3 = PAIR_CDR( r2455 );
        X2 = comma_flesh_2dout( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
}

DEFTSCP( comma_replace_2dtext_v );
DEFSTRING( t3962, "REPLACE-TEXT", 12 );

TSCP  comma_replace_2dtext( f2495, t2496, l2497 )
        TSCP  f2495, t2496, l2497;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3962 ) ) );
        if  ( EQ( UNSIGNED( l2497 ), UNSIGNED( EMPTYLIST ) ) )  goto  L3964;
        if  ( EQ( TSCPTAG( l2497 ), PAIRTAG ) )  goto  L3969;
        scrt1__24__car_2derror( l2497 );
L3969:
        X1 = PAIR_CAR( l2497 );
        if  ( NEQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L3966;
        X2 = PAIR_CAR( l2497 );
        X1 = comma_replace_2dtext( f2495, t2496, X2 );
        X3 = PAIR_CDR( l2497 );
        X2 = comma_replace_2dtext( f2495, t2496, X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3966:
        if  ( EQ( TSCPTAG( l2497 ), PAIRTAG ) )  goto  L3976;
        scrt1__24__car_2derror( l2497 );
L3976:
        X1 = PAIR_CAR( l2497 );
        if  ( NEQ( UNSIGNED( X1 ), UNSIGNED( f2495 ) ) )  goto  L3973;
        X2 = PAIR_CDR( l2497 );
        X1 = comma_replace_2dtext( f2495, t2496, X2 );
        POPSTACKTRACE( sc_cons( t2496, X1 ) );
L3973:
        if  ( EQ( TSCPTAG( l2497 ), PAIRTAG ) )  goto  L3980;
        scrt1__24__car_2derror( l2497 );
L3980:
        X1 = PAIR_CAR( l2497 );
        X3 = PAIR_CDR( l2497 );
        X2 = comma_replace_2dtext( f2495, t2496, X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L3964:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_comma_v );
DEFSTRING( t3983, "COMMA", 5 );
EXTERNTSCPP( comma_output );
EXTERNTSCP( comma_output_v );
EXTERNTSCPP( comma_seq_2d_3elist );
EXTERNTSCP( comma_seq_2d_3elist_v );
EXTERNTSCPP( scrt3_string_2dappend );
EXTERNTSCP( scrt3_string_2dappend_v );

TSCP  comma_comma( i2538, m2539 )
        TSCP  i2538, m2539;
{
        TSCP  X6, X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t3983 ) ) );
        if  ( BITAND( BITOR( INT( m2539 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L3986;
        if  ( EQ( UNSIGNED( m2539 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L3990;
        goto L3991;
L3986:
        if  ( FALSE( scrt2__3d_2dtwo( m2539, _TSCP( 4 ) ) ) )  goto  L3991;
L3990:
        X6 = CONS( c2583, EMPTYLIST );
        X5 = scrt3_string_2dappend( CONS( i2538, X6 ) );
        X4 = comma_seq_2d_3elist( X5 );
        X3 = sc_apply_2dtwo( comma_series_v, X4 );
        X2 = comma_connect( X3 );
        POPSTACKTRACE( comma_output( X2 ) );
L3991:
        if  ( BITAND( BITOR( INT( m2539 ), 
                             INT( _TSCP( 8 ) ) ), 
                      3 ) )  goto  L3995;
        if  ( EQ( UNSIGNED( m2539 ), 
                  UNSIGNED( _TSCP( 8 ) ) ) )  goto  L3999;
        goto L4000;
L3995:
        if  ( TRUE( scrt2__3d_2dtwo( m2539, _TSCP( 8 ) ) ) )  goto  L3999;
L4000:
        X4 = CONS( c2583, EMPTYLIST );
        X3 = scrt3_string_2dappend( CONS( i2538, X4 ) );
        X2 = comma_seq_2d_3elist( X3 );
        if  ( EQ( TSCPTAG( X2 ), PAIRTAG ) )  goto  L4007;
        scrt1__24__car_2derror( X2 );
L4007:
        X3 = PAIR_CAR( X2 );
        if  ( NEQ( TSCPTAG( X3 ), PAIRTAG ) )  goto  L4004;
        X1 = PAIR_CAR( X2 );
        goto L4005;
L4004:
        X1 = X2;
L4005:
        if  ( BITAND( BITOR( INT( m2539 ), 
                             INT( _TSCP( 12 ) ) ), 
                      3 ) )  goto  L4012;
        if  ( EQ( UNSIGNED( m2539 ), 
                  UNSIGNED( _TSCP( 12 ) ) ) )  goto  L4016;
        goto L4017;
L4012:
        if  ( FALSE( scrt2__3d_2dtwo( m2539, _TSCP( 12 ) ) ) )  goto  L4017;
L4016:
        X3 = sc_apply_2dtwo( comma_mult_v, X1 );
        X2 = comma_connect( X3 );
        POPSTACKTRACE( comma_output( X2 ) );
L4017:
        X3 = sc_apply_2dtwo( comma_mult_v, X1 );
        X2 = comma_prepare( X3 );
        POPSTACKTRACE( comma_output( X2 ) );
L3999:
        X6 = CONS( c2583, EMPTYLIST );
        X5 = scrt3_string_2dappend( CONS( i2538, X6 ) );
        X4 = comma_seq_2d_3elist( X5 );
        X3 = sc_apply_2dtwo( comma_series_v, X4 );
        X2 = comma_prepare( X3 );
        POPSTACKTRACE( comma_output( X2 ) );
}

DEFTSCP( comma_comma_2dt_v );
DEFSTRING( t4020, "COMMA-T", 7 );

TSCP  comma_comma_2dt( i2586 )
        TSCP  i2586;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4020 ) ) );
        X5 = CONS( c2583, EMPTYLIST );
        X4 = scrt3_string_2dappend( CONS( i2586, X5 ) );
        X3 = comma_seq_2d_3elist( X4 );
        X2 = sc_apply_2dtwo( comma_series_v, X3 );
        X1 = comma_prepare( X2 );
        POPSTACKTRACE( comma_output( X1 ) );
}

DEFTSCP( comma_output_v );
DEFSTRING( t4022, "OUTPUT", 6 );
DEFSTRING( t4025, "OUTPUT-HELPER [inside OUTPUT]", 29 );
EXTERNTSCPP( scrt3_list_2d_3estring );
EXTERNTSCP( scrt3_list_2d_3estring_v );
EXTERNTSCPP( comma_o2593 );
EXTERNTSCPP( comma_s2594 );

TSCP  comma_o2593( r2596 )
        TSCP  r2596;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4025 ) ) );
        if  ( NEQ( UNSIGNED( r2596 ), 
                   UNSIGNED( EMPTYLIST ) ) )  goto  L4027;
        POPSTACKTRACE( scrt3_list_2d_3estring( c2610 ) );
L4027:
        if  ( EQ( TSCPTAG( r2596 ), PAIRTAG ) )  goto  L4030;
        scrt1__24__cdr_2derror( r2596 );
L4030:
        X2 = PAIR_CDR( r2596 );
        X1 = CONS( comma_o2593( X2 ), EMPTYLIST );
        X2 = PAIR_CAR( r2596 );
        POPSTACKTRACE( scrt3_string_2dappend( CONS( comma_s2594( X2 ), 
                                                    X1 ) ) );
}

DEFSTRING( t4033, "SINGLE-OUTPUT-HELPER [inside OUTPUT]", 36 );
EXTERNTSCPP( scrt2_number_2d_3estring );
EXTERNTSCP( scrt2_number_2d_3estring_v );

TSCP  comma_s2594( s2612 )
        TSCP  s2612;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4033 ) ) );
        if  ( NEQ( UNSIGNED( s2612 ), 
                   UNSIGNED( EMPTYLIST ) ) )  goto  L4035;
        POPSTACKTRACE( scrt3_list_2d_3estring( c2610 ) );
L4035:
        if  ( EQ( TSCPTAG( s2612 ), PAIRTAG ) )  goto  L4038;
        scrt1__24__cdr_2derror( s2612 );
L4038:
        X2 = PAIR_CDR( s2612 );
        X1 = CONS( comma_s2594( X2 ), EMPTYLIST );
        X1 = CONS( c2632, X1 );
        X2 = PAIR_CAR( s2612 );
        if  ( NOT( AND( EQ( TSCPTAG( X2 ), EXTENDEDTAG ), 
                        EQ( TSCP_EXTENDEDTAG( X2 ), SYMBOLTAG ) ) )
            )  goto  L4042;
        X3 = SYMBOL_NAME( X2 );
        goto L4043;
L4042:
        X3 = scrt2_number_2d_3estring( X2, EMPTYLIST );
L4043:
        POPSTACKTRACE( scrt3_string_2dappend( CONS( X3, X1 ) ) );
}

TSCP  comma_output( r2591 )
        TSCP  r2591;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4022 ) ) );
        X1 = CONS( comma_o2593( r2591 ), EMPTYLIST );
        X1 = CONS( c2632, X1 );
        X2 = scrt1_length( r2591 );
        POPSTACKTRACE( scrt3_string_2dappend( CONS( scrt2_number_2d_3estring( X2, 
                                                                              EMPTYLIST ), 
                                                    X1 ) ) );
}

DEFTSCP( comma_seq_2d_3elist_v );
DEFSTRING( t4045, "SEQ->LIST", 9 );
EXTERNTSCPP( comma_no_2dmore_2dnums_3f );
EXTERNTSCP( comma_no_2dmore_2dnums_3f_v );
EXTERNTSCPP( comma__2delement_41c1bc3f );
EXTERNTSCP( comma__2delement_41c1bc3f_v );
EXTERNTSCPP( comma_no_2dspaces_3f );
EXTERNTSCP( comma_no_2dspaces_3f_v );
EXTERNTSCPP( comma_string_2d_3enum );
EXTERNTSCP( comma_string_2d_3enum_v );
EXTERNTSCPP( scrt3_substring );
EXTERNTSCP( scrt3_substring_v );
EXTERNTSCPP( comma_string_2dtail );
EXTERNTSCP( comma_string_2dtail_v );
EXTERNTSCPP( comma__2d_3elist_186a98c0 );
EXTERNTSCP( comma__2d_3elist_186a98c0_v );

TSCP  comma_seq_2d_3elist( s2638 )
        TSCP  s2638;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4045 ) ) );
        if  ( TRUE( comma_no_2dmore_2dnums_3f( s2638 ) ) )  goto  L4047;
        X1 = comma__2delement_41c1bc3f( s2638, _TSCP( 11282 ) );
        if  ( FALSE( comma_no_2dspaces_3f( s2638 ) ) )  goto  L4050;
        X3 = scrt3_substring( s2638, _TSCP( 0 ), X1 );
        X2 = comma_string_2d_3enum( X3 );
        if  ( BITAND( BITOR( INT( _TSCP( 8 ) ), INT( X1 ) ), 
                      3 ) )  goto  L4052;
        X5 = _TSCP( IPLUS( INT( _TSCP( 8 ) ), INT( X1 ) ) );
        goto L4053;
L4052:
        X5 = scrt2__2b_2dtwo( _TSCP( 8 ), X1 );
L4053:
        X4 = comma_string_2dtail( s2638, X5 );
        X3 = comma_seq_2d_3elist( X4 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L4050:
        X4 = CONS( c2632, EMPTYLIST );
        X3 = scrt3_string_2dappend( CONS( scrt3_substring( s2638, 
                                                           _TSCP( 0 ), 
                                                           X1 ), 
                                          X4 ) );
        X2 = comma__2d_3elist_186a98c0( X3 );
        if  ( BITAND( BITOR( INT( _TSCP( 8 ) ), INT( X1 ) ), 
                      3 ) )  goto  L4054;
        X5 = _TSCP( IPLUS( INT( _TSCP( 8 ) ), INT( X1 ) ) );
        goto L4055;
L4054:
        X5 = scrt2__2b_2dtwo( _TSCP( 8 ), X1 );
L4055:
        X4 = comma_string_2dtail( s2638, X5 );
        X3 = comma_seq_2d_3elist( X4 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L4047:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_no_2dspaces_3f_v );
DEFSTRING( t4056, "NO-SPACES?", 10 );
EXTERNTSCPP( comma_string_2dnull_3f );
EXTERNTSCP( comma_string_2dnull_3f_v );
EXTERNTSCPP( scrt3_string_3d_3f );
EXTERNTSCP( scrt3_string_3d_3f_v );
EXTERNTSCPP( comma_string_2dhead );
EXTERNTSCP( comma_string_2dhead_v );

TSCP  comma_no_2dspaces_3f( s2661 )
        TSCP  s2661;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t4056 ) ) );
L4057:
        if  ( TRUE( comma_string_2dnull_3f( s2661 ) ) )  goto  L4058;
        X1 = comma_string_2dhead( s2661, _TSCP( 4 ) );
        if  ( TRUE( scrt3_string_3d_3f( X1, c2668 ) ) )  goto  L4060;
        X1 = comma_string_2dhead( s2661, _TSCP( 4 ) );
        if  ( TRUE( scrt3_string_3d_3f( X1, c2632 ) ) )  goto  L4062;
        s2661 = comma_string_2dtail( s2661, _TSCP( 4 ) );
        goto L4057;
L4062:
        POPSTACKTRACE( EMPTYLIST );
L4060:
        POPSTACKTRACE( TRUEVALUE );
L4058:
        POPSTACKTRACE( TRUEVALUE );
}

DEFTSCP( comma__2d_3elist_186a98c0_v );
DEFSTRING( t4064, "SEQ-WITH-SPACES->LIST", 21 );

TSCP  comma__2d_3elist_186a98c0( s2670 )
        TSCP  s2670;
{
        TSCP  X5, X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4064 ) ) );
        if  ( TRUE( comma_no_2dmore_2dnums_3f( s2670 ) ) )  goto  L4066;
        X1 = comma__2delement_41c1bc3f( s2670, _TSCP( 8210 ) );
        X3 = scrt3_substring( s2670, _TSCP( 0 ), X1 );
        X2 = comma_string_2d_3enum( X3 );
        X5 = comma_add1( X1 );
        X4 = comma_string_2dtail( s2670, X5 );
        X3 = comma__2d_3elist_186a98c0( X4 );
        POPSTACKTRACE( sc_cons( X2, X3 ) );
L4066:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_no_2dmore_2dnums_3f_v );
DEFSTRING( t4069, "NO-MORE-NUMS?", 13 );
EXTERNTSCPP( comma_char_2d_3edigit );
EXTERNTSCP( comma_char_2d_3edigit_v );
EXTERNTSCPP( scrt2__3e_3d_2dtwo );
EXTERNTSCP( scrt2__3e_3d_2dtwo_v );

TSCP  comma_no_2dmore_2dnums_3f( s2675 )
        TSCP  s2675;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4069 ) ) );
L4070:
        if  ( TRUE( comma_string_2dnull_3f( s2675 ) ) )  goto  L4071;
        if  ( EQ( TSCPTAG( _TSCP( 0 ) ), FIXNUMTAG ) )  goto  L4076;
        scrt6_error( c2682, 
                     c2683, CONS( _TSCP( 0 ), EMPTYLIST ) );
L4076:
        X2 = BOOLEAN( LT( INT( _TSCP( 0 ) ), 0 ) );
        if  ( TRUE( X2 ) )  goto  L4082;
        if  ( AND( EQ( TSCPTAG( s2675 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( s2675 ), STRINGTAG ) )
            )  goto  L4084;
        scrt6_error( c2704, 
                     c2705, CONS( s2675, EMPTYLIST ) );
L4084:
        X3 = C_FIXED( STRING_LENGTH( s2675 ) );
        if  ( BITAND( BITOR( INT( _TSCP( 0 ) ), INT( X3 ) ), 
                      3 ) )  goto  L4088;
        if  ( GTE( INT( _TSCP( 0 ) ), INT( X3 ) ) )  goto  L4082;
        goto L4095;
L4088:
        if  ( FALSE( scrt2__3e_3d_2dtwo( _TSCP( 0 ), X3 ) ) )  goto  L4095;
L4082:
        scrt6_error( c2682, 
                     c2706, CONS( _TSCP( 0 ), EMPTYLIST ) );
L4095:
        X1 = C_CHAR( STRING_CHAR( s2675, _TSCP( 0 ) ) );
        if  ( TRUE( comma_char_2d_3edigit( X1 ) ) )  goto  L4073;
        s2675 = comma_string_2dtail( s2675, _TSCP( 4 ) );
        goto L4070;
L4073:
        POPSTACKTRACE( EMPTYLIST );
L4071:
        POPSTACKTRACE( TRUEVALUE );
}

DEFTSCP( comma__2delement_41c1bc3f_v );
DEFSTRING( t4096, "LENGTH-FIRST-ELEMENT", 20 );

TSCP  comma__2delement_41c1bc3f( s2708, c2709 )
        TSCP  s2708, c2709;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4096 ) ) );
        if  ( TRUE( comma_string_2dnull_3f( s2708 ) ) )  goto  L4098;
        if  ( EQ( TSCPTAG( _TSCP( 0 ) ), FIXNUMTAG ) )  goto  L4101;
        scrt6_error( c2682, 
                     c2683, CONS( _TSCP( 0 ), EMPTYLIST ) );
L4101:
        X2 = BOOLEAN( LT( INT( _TSCP( 0 ) ), 0 ) );
        if  ( TRUE( X2 ) )  goto  L4107;
        if  ( AND( EQ( TSCPTAG( s2708 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( s2708 ), STRINGTAG ) )
            )  goto  L4109;
        scrt6_error( c2704, 
                     c2705, CONS( s2708, EMPTYLIST ) );
L4109:
        X3 = C_FIXED( STRING_LENGTH( s2708 ) );
        if  ( BITAND( BITOR( INT( _TSCP( 0 ) ), INT( X3 ) ), 
                      3 ) )  goto  L4113;
        if  ( GTE( INT( _TSCP( 0 ) ), INT( X3 ) ) )  goto  L4107;
        goto L4120;
L4113:
        if  ( FALSE( scrt2__3e_3d_2dtwo( _TSCP( 0 ), X3 ) ) )  goto  L4120;
L4107:
        scrt6_error( c2682, 
                     c2706, CONS( _TSCP( 0 ), EMPTYLIST ) );
L4120:
        X1 = C_CHAR( STRING_CHAR( s2708, _TSCP( 0 ) ) );
        if  ( AND( EQ( TSCPIMMEDIATETAG( X1 ), CHARACTERTAG ), 
                   EQ( TSCPIMMEDIATETAG( c2709 ), CHARACTERTAG ) )
            )  goto  L4122;
        X2 = CONS( c2709, EMPTYLIST );
        scrt6_error( c2720, c2721, CONS( X1, X2 ) );
L4122:
        if  ( EQ( INT( X1 ), INT( c2709 ) ) )  goto  L4124;
        X3 = comma_string_2dtail( s2708, _TSCP( 4 ) );
        X2 = comma__2delement_41c1bc3f( X3, c2709 );
        POPSTACKTRACE( comma_add1( X2 ) );
L4124:
        POPSTACKTRACE( _TSCP( 0 ) );
L4098:
        POPSTACKTRACE( _TSCP( 0 ) );
}

DEFTSCP( comma_string_2d_3enum_v );
DEFSTRING( t4126, "STRING->NUM", 11 );
EXTERNTSCPP( scrt2_string_2d_3enumber );
EXTERNTSCP( scrt2_string_2d_3enumber_v );

TSCP  comma_string_2d_3enum( s2748 )
        TSCP  s2748;
{
        PUSHSTACKTRACE( U_TX( ADR( t4126 ) ) );
        if  ( TRUE( comma_string_2dnull_3f( s2748 ) ) )  goto  L4128;
        POPSTACKTRACE( scrt2_string_2d_3enumber( s2748, EMPTYLIST ) );
L4128:
        POPSTACKTRACE( _TSCP( 0 ) );
}

DEFTSCP( comma_reverse_2dstring_v );
DEFSTRING( t4130, "REVERSE-STRING", 14 );
EXTERNTSCPP( comma_reverse_2dstring );
EXTERNTSCP( comma_reverse_2dstring_v );
EXTERNTSCP( sc_emptystring );

TSCP  comma_reverse_2dstring( s2751 )
        TSCP  s2751;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4130 ) ) );
        if  ( TRUE( comma_string_2dnull_3f( s2751 ) ) )  goto  L4132;
        X1 = CONS( comma_string_2dhead( s2751, _TSCP( 4 ) ), 
                   EMPTYLIST );
        X2 = comma_string_2dtail( s2751, _TSCP( 4 ) );
        POPSTACKTRACE( scrt3_string_2dappend( CONS( comma_reverse_2dstring( X2 ), 
                                                    X1 ) ) );
L4132:
        POPSTACKTRACE( sc_emptystring );
}

DEFTSCP( comma_done_v );
DEFSTRING( t4134, "DONE", 4 );
DEFTSCP( comma_add_2dparens_v );
DEFSTRING( t4135, "ADD-PARENS", 10 );
EXTERNTSCPP( comma_add_2dparens );
EXTERNTSCP( comma_add_2dparens_v );

TSCP  comma_add_2dparens( l2755 )
        TSCP  l2755;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4135 ) ) );
        if  ( EQ( UNSIGNED( l2755 ), UNSIGNED( EMPTYLIST ) ) )  goto  L4137;
        if  ( EQ( TSCPTAG( l2755 ), PAIRTAG ) )  goto  L4142;
        scrt1__24__car_2derror( l2755 );
L4142:
        X1 = PAIR_CAR( l2755 );
        if  ( NEQ( TSCPTAG( X1 ), PAIRTAG ) )  goto  L4139;
        X1 = PAIR_CAR( l2755 );
        X3 = PAIR_CDR( l2755 );
        X2 = comma_add_2dparens( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L4139:
        if  ( EQ( TSCPTAG( l2755 ), PAIRTAG ) )  goto  L4147;
        scrt1__24__car_2derror( l2755 );
L4147:
        X3 = PAIR_CAR( l2755 );
        X2 = sc_cons( X3, EMPTYLIST );
        X1 = X2;
        X3 = PAIR_CDR( l2755 );
        X2 = comma_add_2dparens( X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L4137:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_sublist_v );
DEFSTRING( t4151, "SUBLIST", 7 );
EXTERNTSCPP( comma_sublist );
EXTERNTSCP( comma_sublist_v );

TSCP  comma_sublist( l2787, s2788, e2789 )
        TSCP  l2787, s2788, e2789;
{
        TSCP  X4, X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4151 ) ) );
L4152:
        if  ( NEQ( TSCPTAG( s2788 ), FIXNUMTAG ) )  goto  L4154;
        if  ( EQ( UNSIGNED( s2788 ), 
                  UNSIGNED( _TSCP( 0 ) ) ) )  goto  L4158;
        goto L4159;
L4154:
        if  ( FALSE( scrt2_zero_3f( s2788 ) ) )  goto  L4159;
L4158:
        if  ( BITAND( BITOR( INT( e2789 ), 
                             INT( _TSCP( 4 ) ) ), 
                      3 ) )  goto  L4163;
        if  ( EQ( UNSIGNED( e2789 ), 
                  UNSIGNED( _TSCP( 4 ) ) ) )  goto  L4167;
        goto L4168;
L4163:
        if  ( TRUE( scrt2__3d_2dtwo( e2789, _TSCP( 4 ) ) ) )  goto  L4167;
L4168:
        if  ( EQ( TSCPTAG( l2787 ), PAIRTAG ) )  goto  L4172;
        scrt1__24__car_2derror( l2787 );
L4172:
        X1 = PAIR_CAR( l2787 );
        X3 = PAIR_CDR( l2787 );
        X4 = comma_sub1( e2789 );
        X2 = comma_sublist( X3, _TSCP( 0 ), X4 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L4167:
        if  ( EQ( TSCPTAG( l2787 ), PAIRTAG ) )  goto  L4176;
        scrt1__24__car_2derror( l2787 );
L4176:
        X2 = PAIR_CAR( l2787 );
        X1 = sc_cons( X2, EMPTYLIST );
        POPSTACKTRACE( X1 );
L4159:
        if  ( EQ( TSCPTAG( l2787 ), PAIRTAG ) )  goto  L4180;
        scrt1__24__cdr_2derror( l2787 );
L4180:
        X1 = PAIR_CDR( l2787 );
        X2 = comma_sub1( s2788 );
        e2789 = comma_sub1( e2789 );
        s2788 = X2;
        l2787 = X1;
        goto L4152;
}

DEFTSCP( comma_list_2dhead_v );
DEFSTRING( t4182, "LIST-HEAD", 9 );

TSCP  comma_list_2dhead( l2827, k2828 )
        TSCP  l2827, k2828;
{
        PUSHSTACKTRACE( U_TX( ADR( t4182 ) ) );
        POPSTACKTRACE( comma_sublist( l2827, _TSCP( 0 ), k2828 ) );
}

DEFTSCP( comma_delq_v );
DEFSTRING( t4184, "DELQ", 4 );

TSCP  comma_delq( e2830, l2831 )
        TSCP  e2830, l2831;
{
        TSCP  X3, X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4184 ) ) );
L4185:
        if  ( EQ( UNSIGNED( l2831 ), UNSIGNED( EMPTYLIST ) ) )  goto  L4186;
        if  ( EQ( TSCPTAG( l2831 ), PAIRTAG ) )  goto  L4191;
        scrt1__24__car_2derror( l2831 );
L4191:
        X1 = PAIR_CAR( l2831 );
        if  ( NEQ( UNSIGNED( X1 ), UNSIGNED( e2830 ) ) )  goto  L4188;
        l2831 = PAIR_CDR( l2831 );
        goto L4185;
L4188:
        if  ( EQ( TSCPTAG( l2831 ), PAIRTAG ) )  goto  L4195;
        scrt1__24__car_2derror( l2831 );
L4195:
        X1 = PAIR_CAR( l2831 );
        X3 = PAIR_CDR( l2831 );
        X2 = comma_delq( e2830, X3 );
        POPSTACKTRACE( sc_cons( X1, X2 ) );
L4186:
        POPSTACKTRACE( EMPTYLIST );
}

DEFTSCP( comma_boolean_3d_3f_v );
DEFSTRING( t4198, "BOOLEAN=?", 9 );
EXTERNTSCPP( scrt1_equal_3f );
EXTERNTSCP( scrt1_equal_3f_v );

TSCP  comma_boolean_3d_3f( a2857, b2858 )
        TSCP  a2857, b2858;
{
        TSCP  X1;

        PUSHSTACKTRACE( U_TX( ADR( t4198 ) ) );
        X1 = scrt1_equal_3f( a2857, FALSEVALUE );
        if  ( TRUE( X1 ) )  goto  L4204;
        if  ( TRUE( scrt1_equal_3f( a2857, EMPTYLIST ) ) )  goto  L4204;
        if  ( TRUE( scrt1_equal_3f( b2858, FALSEVALUE ) ) )  goto  L4207;
        if  ( TRUE( scrt1_equal_3f( b2858, EMPTYLIST ) ) )  goto  L4209;
        POPSTACKTRACE( TRUEVALUE );
L4209:
        POPSTACKTRACE( FALSEVALUE );
L4207:
        POPSTACKTRACE( FALSEVALUE );
L4204:
        if  ( TRUE( scrt1_equal_3f( b2858, FALSEVALUE ) ) )  goto  L4211;
        if  ( TRUE( scrt1_equal_3f( b2858, EMPTYLIST ) ) )  goto  L4213;
        POPSTACKTRACE( FALSEVALUE );
L4213:
        POPSTACKTRACE( TRUEVALUE );
L4211:
        POPSTACKTRACE( TRUEVALUE );
}

DEFTSCP( comma_string_2dnull_3f_v );
DEFSTRING( t4215, "STRING-NULL?", 12 );
EXTERNTSCPP( scrt3_string_2dci_3d_3f );
EXTERNTSCP( scrt3_string_2dci_3d_3f_v );

TSCP  comma_string_2dnull_3f( s2872 )
        TSCP  s2872;
{
        PUSHSTACKTRACE( U_TX( ADR( t4215 ) ) );
        POPSTACKTRACE( scrt3_string_2dci_3d_3f( s2872, sc_emptystring ) );
}

DEFTSCP( comma_string_2dtail_v );
DEFSTRING( t4217, "STRING-TAIL", 11 );

TSCP  comma_string_2dtail( s2874, n2875 )
        TSCP  s2874, n2875;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4217 ) ) );
        if  ( AND( EQ( TSCPTAG( s2874 ), EXTENDEDTAG ), 
                   EQ( TSCP_EXTENDEDTAG( s2874 ), STRINGTAG ) )
            )  goto  L4220;
        scrt6_error( c2704, 
                     c2705, CONS( s2874, EMPTYLIST ) );
L4220:
        X1 = C_FIXED( STRING_LENGTH( s2874 ) );
        POPSTACKTRACE( scrt3_substring( s2874, n2875, X1 ) );
}

DEFTSCP( comma_string_2dhead_v );
DEFSTRING( t4222, "STRING-HEAD", 11 );

TSCP  comma_string_2dhead( s2881, n2882 )
        TSCP  s2881, n2882;
{
        PUSHSTACKTRACE( U_TX( ADR( t4222 ) ) );
        POPSTACKTRACE( scrt3_substring( s2881, _TSCP( 0 ), n2882 ) );
}

DEFTSCP( comma_char_2d_3edigit_v );
DEFSTRING( t4224, "CHAR->DIGIT", 11 );

TSCP  comma_char_2d_3edigit( c2884 )
        TSCP  c2884;
{
        TSCP  X2, X1;

        PUSHSTACKTRACE( U_TX( ADR( t4224 ) ) );
        if  ( EQ( TSCPIMMEDIATETAG( c2884 ), CHARACTERTAG ) )  goto  L4227;
        scrt6_error( c2895, 
                     c2896, CONS( c2884, EMPTYLIST ) );
L4227:
        X1 = CHAR_FIX( c2884 );
        if  ( BITAND( BITOR( INT( X1 ), 
                             INT( _TSCP( 192 ) ) ), 
                      3 ) )  goto  L4230;
        POPSTACKTRACE( _TSCP( IDIFFERENCE( INT( X1 ), 
                                           INT( _TSCP( 192 ) ) ) ) );
L4230:
        POPSTACKTRACE( scrt2__2d_2dtwo( X1, _TSCP( 192 ) ) );
}

static void  init_modules( compiler_version )
        char *compiler_version;
{
        scrt3__init();
        scrt6__init();
        scrt2__init();
        scrt1__init();
        MAXDISPLAY( 3 );
}

void  comma__init()
{
        static int  init = 0;
        if  (init)  return;
        init = 1;
        INITHEAP( 0, 0, 0, 0 );
        init_constants();
        init_modules( "(comma SCHEME->C COMPILER 28sep90jfb)" );
        INITIALIZEVAR( U_TX( ADR( t3087 ) ), 
                       ADR( comma_call_2fcc_v ), 
                       sc_ntinuation_1af38b9f_v );
        INITIALIZEVAR( U_TX( ADR( t3088 ) ), 
                       ADR( comma_newlist_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_newlist, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3103 ) ), 
                       ADR( comma_carof_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_carof, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3111 ) ), 
                       ADR( comma_add1_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_add1, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3115 ) ), 
                       ADR( comma_sub1_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_sub1, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3119 ) ), 
                       ADR( comma_int_2d_3erep_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_int_2d_3erep, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3183 ) ), 
                       ADR( comma_row_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_row, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3200 ) ), 
                       ADR( comma_direction_2dcell_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_direction_2dcell, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3202 ) ), 
                       ADR( comma_direction_v ), 
                       comma_carof( comma_direction_2dcell_v ) );
        INITIALIZEVAR( U_TX( ADR( t3203 ) ), 
                       ADR( comma_over_2dknot_2dcell_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_over_2dknot_2dcell, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3208 ) ), 
                       ADR( comma_over_2dknot_v ), 
                       comma_carof( comma_over_2dknot_2dcell_v ) );
        INITIALIZEVAR( U_TX( ADR( t3209 ) ), 
                       ADR( comma_over_2dpos_2dcell_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_over_2dpos_2dcell, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3218 ) ), 
                       ADR( comma_over_2dpos_v ), 
                       comma_carof( comma_over_2dpos_2dcell_v ) );
        INITIALIZEVAR( U_TX( ADR( t3219 ) ), 
                       ADR( comma_under_2dknot_2dcell_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_under_2dknot_2dcell, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3221 ) ), 
                       ADR( comma_under_2dknot_v ), 
                       comma_carof( comma_under_2dknot_2dcell_v ) );
        INITIALIZEVAR( U_TX( ADR( t3222 ) ), 
                       ADR( comma_under_2dpos_2dcell_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_under_2dpos_2dcell, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3227 ) ), 
                       ADR( comma_under_2dpos_v ), 
                       comma_carof( comma_under_2dpos_2dcell_v ) );
        INITIALIZEVAR( U_TX( ADR( t3228 ) ), 
                       ADR( comma_compose_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_compose, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3233 ) ), 
                       ADR( comma_nw_2dknot_v ), scrt1_caar_v );
        INITIALIZEVAR( U_TX( ADR( t3234 ) ), 
                       ADR( comma_nw_2dpos_v ), scrt1_cadar_v );
        INITIALIZEVAR( U_TX( ADR( t3235 ) ), 
                       ADR( comma_ne_2dknot_v ), scrt1_caadr_v );
        INITIALIZEVAR( U_TX( ADR( t3236 ) ), 
                       ADR( comma_ne_2dpos_v ), scrt1_cadadr_v );
        INITIALIZEVAR( U_TX( ADR( t3237 ) ), 
                       ADR( comma_sw_2dknot_v ), scrt1_caaddr_v );
        INITIALIZEVAR( U_TX( ADR( t3238 ) ), 
                       ADR( comma_sw_2dpos_v ), 
                       comma_compose( scrt1_cadadr_v, scrt1_cdr_v ) );
        INITIALIZEVAR( U_TX( ADR( t3239 ) ), 
                       ADR( comma_se_2dknot_v ), 
                       comma_compose( scrt1_caaddr_v, scrt1_cdr_v ) );
        INITIALIZEVAR( U_TX( ADR( t3240 ) ), 
                       ADR( comma_se_2dpos_v ), 
                       comma_compose( scrt1_cadadr_v, scrt1_cddr_v ) );
        INITIALIZEVAR( U_TX( ADR( t3241 ) ), 
                       ADR( comma_select_2dorigin_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_select_2dorigin, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3251 ) ), 
                       ADR( comma_mult0_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_mult0, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3298 ) ), 
                       ADR( comma_recur_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_recur, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3311 ) ), 
                       ADR( comma_renumber_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_renumber, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3370 ) ), 
                       ADR( comma_construct_21_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, 
                                      comma_construct_21, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3455 ) ), 
                       ADR( comma_make_2dpath_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_make_2dpath, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3491 ) ), 
                       ADR( comma_reverse_2dpath_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_reverse_2dpath, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3495 ) ), 
                       ADR( comma_sum_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_sum, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3613 ) ), 
                       ADR( comma_direct_2dreps_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_direct_2dreps, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3624 ) ), 
                       ADR( comma_connected_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_connected_3f, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3652 ) ), 
                       ADR( comma_ted_2dreps_ec8f8b13_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_ted_2dreps_ec8f8b13, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3658 ) ), 
                       ADR( comma_direct_2d1nc_2dreps_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_direct_2d1nc_2dreps, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3667 ) ), 
                       ADR( comma_direct_2d2nc_2dreps_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_direct_2d2nc_2dreps, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3676 ) ), 
                       ADR( comma_opposite_2dend_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_opposite_2dend, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3710 ) ), 
                       ADR( comma_reverse_2dstrand_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_reverse_2dstrand, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3731 ) ), 
                       ADR( comma_change_2dorigin_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, 
                                      comma_change_2dorigin, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3767 ) ), 
                       ADR( comma_junkate_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_junkate, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3770 ) ), 
                       ADR( comma_reverse_2ddirections_21_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_reverse_2ddirections_21, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3801 ) ), 
                       ADR( comma_mult_v ), 
                       MAKEPROCEDURE( 0, 
                                      1, comma_mult, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3839 ) ), 
                       ADR( comma_expand_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_expand, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3865 ) ), 
                       ADR( comma_rat_2d_3erep_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_rat_2d_3erep, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3867 ) ), 
                       ADR( comma_series_v ), 
                       MAKEPROCEDURE( 0, 
                                      1, comma_series, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3885 ) ), 
                       ADR( comma_connect_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_connect, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3937 ) ), 
                       ADR( comma_prepare_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_prepare, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3939 ) ), 
                       ADR( comma_flesh_2dout_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_flesh_2dout, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3962 ) ), 
                       ADR( comma_replace_2dtext_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, 
                                      comma_replace_2dtext, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t3983 ) ), 
                       ADR( comma_comma_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_comma, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4020 ) ), 
                       ADR( comma_comma_2dt_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_comma_2dt, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4022 ) ), 
                       ADR( comma_output_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, comma_output, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4045 ) ), 
                       ADR( comma_seq_2d_3elist_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_seq_2d_3elist, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4056 ) ), 
                       ADR( comma_no_2dspaces_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_no_2dspaces_3f, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4064 ) ), 
                       ADR( comma__2d_3elist_186a98c0_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma__2d_3elist_186a98c0, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4069 ) ), 
                       ADR( comma_no_2dmore_2dnums_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_no_2dmore_2dnums_3f, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4096 ) ), 
                       ADR( comma__2delement_41c1bc3f_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma__2delement_41c1bc3f, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4126 ) ), 
                       ADR( comma_string_2d_3enum_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_string_2d_3enum, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4130 ) ), 
                       ADR( comma_reverse_2dstring_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_reverse_2dstring, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4134 ) ), 
                       ADR( comma_done_v ), EMPTYLIST );
        INITIALIZEVAR( U_TX( ADR( t4135 ) ), 
                       ADR( comma_add_2dparens_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_add_2dparens, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4151 ) ), 
                       ADR( comma_sublist_v ), 
                       MAKEPROCEDURE( 3, 
                                      0, comma_sublist, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4182 ) ), 
                       ADR( comma_list_2dhead_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_list_2dhead, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4184 ) ), 
                       ADR( comma_delq_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, comma_delq, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4198 ) ), 
                       ADR( comma_boolean_3d_3f_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_boolean_3d_3f, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4215 ) ), 
                       ADR( comma_string_2dnull_3f_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_string_2dnull_3f, 
                                      EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4217 ) ), 
                       ADR( comma_string_2dtail_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_string_2dtail, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4222 ) ), 
                       ADR( comma_string_2dhead_v ), 
                       MAKEPROCEDURE( 2, 
                                      0, 
                                      comma_string_2dhead, EMPTYLIST ) );
        INITIALIZEVAR( U_TX( ADR( t4224 ) ), 
                       ADR( comma_char_2d_3edigit_v ), 
                       MAKEPROCEDURE( 1, 
                                      0, 
                                      comma_char_2d_3edigit, EMPTYLIST ) );
        return;
}
